/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ApphubApplicationConfig extends cdktf.TerraformMetaArguments {
    /**
    * Required. The Application identifier.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#application_id ApphubApplication#application_id}
    */
    readonly applicationId: string;
    /**
    * Optional. User-defined description of an Application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#description ApphubApplication#description}
    */
    readonly description?: string;
    /**
    * Optional. User-defined name for the Application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#display_name ApphubApplication#display_name}
    */
    readonly displayName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#id ApphubApplication#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Part of 'parent'. See documentation of 'projectsId'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#location ApphubApplication#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#project ApphubApplication#project}
    */
    readonly project?: string;
    /**
    * attributes block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#attributes ApphubApplication#attributes}
    */
    readonly attributes?: ApphubApplicationAttributes;
    /**
    * scope block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#scope ApphubApplication#scope}
    */
    readonly scope: ApphubApplicationScope;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#timeouts ApphubApplication#timeouts}
    */
    readonly timeouts?: ApphubApplicationTimeouts;
}
export interface ApphubApplicationAttributesBusinessOwners {
    /**
    * Optional. Contact's name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#display_name ApphubApplication#display_name}
    */
    readonly displayName?: string;
    /**
    * Required. Email address of the contacts.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#email ApphubApplication#email}
    */
    readonly email: string;
}
export declare function apphubApplicationAttributesBusinessOwnersToTerraform(struct?: ApphubApplicationAttributesBusinessOwners | cdktf.IResolvable): any;
export declare function apphubApplicationAttributesBusinessOwnersToHclTerraform(struct?: ApphubApplicationAttributesBusinessOwners | cdktf.IResolvable): any;
export declare class ApphubApplicationAttributesBusinessOwnersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ApphubApplicationAttributesBusinessOwners | cdktf.IResolvable | undefined;
    set internalValue(value: ApphubApplicationAttributesBusinessOwners | cdktf.IResolvable | undefined);
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _email?;
    get email(): string;
    set email(value: string);
    get emailInput(): string | undefined;
}
export declare class ApphubApplicationAttributesBusinessOwnersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ApphubApplicationAttributesBusinessOwners[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ApphubApplicationAttributesBusinessOwnersOutputReference;
}
export interface ApphubApplicationAttributesCriticality {
    /**
    * Criticality type. Possible values: ["MISSION_CRITICAL", "HIGH", "MEDIUM", "LOW"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#type ApphubApplication#type}
    */
    readonly type: string;
}
export declare function apphubApplicationAttributesCriticalityToTerraform(struct?: ApphubApplicationAttributesCriticalityOutputReference | ApphubApplicationAttributesCriticality): any;
export declare function apphubApplicationAttributesCriticalityToHclTerraform(struct?: ApphubApplicationAttributesCriticalityOutputReference | ApphubApplicationAttributesCriticality): any;
export declare class ApphubApplicationAttributesCriticalityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ApphubApplicationAttributesCriticality | undefined;
    set internalValue(value: ApphubApplicationAttributesCriticality | undefined);
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
}
export interface ApphubApplicationAttributesDeveloperOwners {
    /**
    * Optional. Contact's name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#display_name ApphubApplication#display_name}
    */
    readonly displayName?: string;
    /**
    * Required. Email address of the contacts.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#email ApphubApplication#email}
    */
    readonly email: string;
}
export declare function apphubApplicationAttributesDeveloperOwnersToTerraform(struct?: ApphubApplicationAttributesDeveloperOwners | cdktf.IResolvable): any;
export declare function apphubApplicationAttributesDeveloperOwnersToHclTerraform(struct?: ApphubApplicationAttributesDeveloperOwners | cdktf.IResolvable): any;
export declare class ApphubApplicationAttributesDeveloperOwnersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ApphubApplicationAttributesDeveloperOwners | cdktf.IResolvable | undefined;
    set internalValue(value: ApphubApplicationAttributesDeveloperOwners | cdktf.IResolvable | undefined);
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _email?;
    get email(): string;
    set email(value: string);
    get emailInput(): string | undefined;
}
export declare class ApphubApplicationAttributesDeveloperOwnersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ApphubApplicationAttributesDeveloperOwners[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ApphubApplicationAttributesDeveloperOwnersOutputReference;
}
export interface ApphubApplicationAttributesEnvironment {
    /**
    * Environment type. Possible values: ["PRODUCTION", "STAGING", "TEST", "DEVELOPMENT"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#type ApphubApplication#type}
    */
    readonly type: string;
}
export declare function apphubApplicationAttributesEnvironmentToTerraform(struct?: ApphubApplicationAttributesEnvironmentOutputReference | ApphubApplicationAttributesEnvironment): any;
export declare function apphubApplicationAttributesEnvironmentToHclTerraform(struct?: ApphubApplicationAttributesEnvironmentOutputReference | ApphubApplicationAttributesEnvironment): any;
export declare class ApphubApplicationAttributesEnvironmentOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ApphubApplicationAttributesEnvironment | undefined;
    set internalValue(value: ApphubApplicationAttributesEnvironment | undefined);
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
}
export interface ApphubApplicationAttributesOperatorOwners {
    /**
    * Optional. Contact's name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#display_name ApphubApplication#display_name}
    */
    readonly displayName?: string;
    /**
    * Required. Email address of the contacts.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#email ApphubApplication#email}
    */
    readonly email: string;
}
export declare function apphubApplicationAttributesOperatorOwnersToTerraform(struct?: ApphubApplicationAttributesOperatorOwners | cdktf.IResolvable): any;
export declare function apphubApplicationAttributesOperatorOwnersToHclTerraform(struct?: ApphubApplicationAttributesOperatorOwners | cdktf.IResolvable): any;
export declare class ApphubApplicationAttributesOperatorOwnersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ApphubApplicationAttributesOperatorOwners | cdktf.IResolvable | undefined;
    set internalValue(value: ApphubApplicationAttributesOperatorOwners | cdktf.IResolvable | undefined);
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _email?;
    get email(): string;
    set email(value: string);
    get emailInput(): string | undefined;
}
export declare class ApphubApplicationAttributesOperatorOwnersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ApphubApplicationAttributesOperatorOwners[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ApphubApplicationAttributesOperatorOwnersOutputReference;
}
export interface ApphubApplicationAttributes {
    /**
    * business_owners block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#business_owners ApphubApplication#business_owners}
    */
    readonly businessOwners?: ApphubApplicationAttributesBusinessOwners[] | cdktf.IResolvable;
    /**
    * criticality block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#criticality ApphubApplication#criticality}
    */
    readonly criticality?: ApphubApplicationAttributesCriticality;
    /**
    * developer_owners block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#developer_owners ApphubApplication#developer_owners}
    */
    readonly developerOwners?: ApphubApplicationAttributesDeveloperOwners[] | cdktf.IResolvable;
    /**
    * environment block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#environment ApphubApplication#environment}
    */
    readonly environment?: ApphubApplicationAttributesEnvironment;
    /**
    * operator_owners block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#operator_owners ApphubApplication#operator_owners}
    */
    readonly operatorOwners?: ApphubApplicationAttributesOperatorOwners[] | cdktf.IResolvable;
}
export declare function apphubApplicationAttributesToTerraform(struct?: ApphubApplicationAttributesOutputReference | ApphubApplicationAttributes): any;
export declare function apphubApplicationAttributesToHclTerraform(struct?: ApphubApplicationAttributesOutputReference | ApphubApplicationAttributes): any;
export declare class ApphubApplicationAttributesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ApphubApplicationAttributes | undefined;
    set internalValue(value: ApphubApplicationAttributes | undefined);
    private _businessOwners;
    get businessOwners(): ApphubApplicationAttributesBusinessOwnersList;
    putBusinessOwners(value: ApphubApplicationAttributesBusinessOwners[] | cdktf.IResolvable): void;
    resetBusinessOwners(): void;
    get businessOwnersInput(): cdktf.IResolvable | ApphubApplicationAttributesBusinessOwners[] | undefined;
    private _criticality;
    get criticality(): ApphubApplicationAttributesCriticalityOutputReference;
    putCriticality(value: ApphubApplicationAttributesCriticality): void;
    resetCriticality(): void;
    get criticalityInput(): ApphubApplicationAttributesCriticality | undefined;
    private _developerOwners;
    get developerOwners(): ApphubApplicationAttributesDeveloperOwnersList;
    putDeveloperOwners(value: ApphubApplicationAttributesDeveloperOwners[] | cdktf.IResolvable): void;
    resetDeveloperOwners(): void;
    get developerOwnersInput(): cdktf.IResolvable | ApphubApplicationAttributesDeveloperOwners[] | undefined;
    private _environment;
    get environment(): ApphubApplicationAttributesEnvironmentOutputReference;
    putEnvironment(value: ApphubApplicationAttributesEnvironment): void;
    resetEnvironment(): void;
    get environmentInput(): ApphubApplicationAttributesEnvironment | undefined;
    private _operatorOwners;
    get operatorOwners(): ApphubApplicationAttributesOperatorOwnersList;
    putOperatorOwners(value: ApphubApplicationAttributesOperatorOwners[] | cdktf.IResolvable): void;
    resetOperatorOwners(): void;
    get operatorOwnersInput(): cdktf.IResolvable | ApphubApplicationAttributesOperatorOwners[] | undefined;
}
export interface ApphubApplicationScope {
    /**
    * Required. Scope Type.
    *  Possible values:
    * REGIONAL Possible values: ["REGIONAL"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#type ApphubApplication#type}
    */
    readonly type: string;
}
export declare function apphubApplicationScopeToTerraform(struct?: ApphubApplicationScopeOutputReference | ApphubApplicationScope): any;
export declare function apphubApplicationScopeToHclTerraform(struct?: ApphubApplicationScopeOutputReference | ApphubApplicationScope): any;
export declare class ApphubApplicationScopeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ApphubApplicationScope | undefined;
    set internalValue(value: ApphubApplicationScope | undefined);
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
}
export interface ApphubApplicationTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#create ApphubApplication#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#delete ApphubApplication#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#update ApphubApplication#update}
    */
    readonly update?: string;
}
export declare function apphubApplicationTimeoutsToTerraform(struct?: ApphubApplicationTimeouts | cdktf.IResolvable): any;
export declare function apphubApplicationTimeoutsToHclTerraform(struct?: ApphubApplicationTimeouts | cdktf.IResolvable): any;
export declare class ApphubApplicationTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ApphubApplicationTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: ApphubApplicationTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application google_apphub_application}
*/
export declare class ApphubApplication extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_apphub_application";
    /**
    * Generates CDKTF code for importing a ApphubApplication resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ApphubApplication to import
    * @param importFromId The id of the existing ApphubApplication that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ApphubApplication to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_application google_apphub_application} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ApphubApplicationConfig
    */
    constructor(scope: Construct, id: string, config: ApphubApplicationConfig);
    private _applicationId?;
    get applicationId(): string;
    set applicationId(value: string);
    get applicationIdInput(): string | undefined;
    get createTime(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get state(): string;
    get uid(): string;
    get updateTime(): string;
    private _attributes;
    get attributes(): ApphubApplicationAttributesOutputReference;
    putAttributes(value: ApphubApplicationAttributes): void;
    resetAttributes(): void;
    get attributesInput(): ApphubApplicationAttributes | undefined;
    private _scope;
    get scope(): ApphubApplicationScopeOutputReference;
    putScope(value: ApphubApplicationScope): void;
    get scopeInput(): ApphubApplicationScope | undefined;
    private _timeouts;
    get timeouts(): ApphubApplicationTimeoutsOutputReference;
    putTimeouts(value: ApphubApplicationTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | ApphubApplicationTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
