/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataCatalogEntryGroupConfig extends cdktf.TerraformMetaArguments {
    /**
    * Entry group description, which can consist of several sentences or paragraphs that describe entry group contents.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/data_catalog_entry_group#description DataCatalogEntryGroup#description}
    */
    readonly description?: string;
    /**
    * A short name to identify the entry group, for example, "analytics data - jan 2011".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/data_catalog_entry_group#display_name DataCatalogEntryGroup#display_name}
    */
    readonly displayName?: string;
    /**
    * The id of the entry group to create. The id must begin with a letter or underscore,
    * contain only English letters, numbers and underscores, and be at most 64 characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/data_catalog_entry_group#entry_group_id DataCatalogEntryGroup#entry_group_id}
    */
    readonly entryGroupId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/data_catalog_entry_group#id DataCatalogEntryGroup#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/data_catalog_entry_group#project DataCatalogEntryGroup#project}
    */
    readonly project?: string;
    /**
    * EntryGroup location region.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/data_catalog_entry_group#region DataCatalogEntryGroup#region}
    */
    readonly region?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/data_catalog_entry_group#timeouts DataCatalogEntryGroup#timeouts}
    */
    readonly timeouts?: DataCatalogEntryGroupTimeouts;
}
export interface DataCatalogEntryGroupTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/data_catalog_entry_group#create DataCatalogEntryGroup#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/data_catalog_entry_group#delete DataCatalogEntryGroup#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/data_catalog_entry_group#update DataCatalogEntryGroup#update}
    */
    readonly update?: string;
}
export declare function dataCatalogEntryGroupTimeoutsToTerraform(struct?: DataCatalogEntryGroupTimeouts | cdktf.IResolvable): any;
export declare function dataCatalogEntryGroupTimeoutsToHclTerraform(struct?: DataCatalogEntryGroupTimeouts | cdktf.IResolvable): any;
export declare class DataCatalogEntryGroupTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataCatalogEntryGroupTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: DataCatalogEntryGroupTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/data_catalog_entry_group google_data_catalog_entry_group}
*/
export declare class DataCatalogEntryGroup extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_data_catalog_entry_group";
    /**
    * Generates CDKTF code for importing a DataCatalogEntryGroup resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataCatalogEntryGroup to import
    * @param importFromId The id of the existing DataCatalogEntryGroup that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/data_catalog_entry_group#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataCatalogEntryGroup to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/data_catalog_entry_group google_data_catalog_entry_group} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataCatalogEntryGroupConfig
    */
    constructor(scope: Construct, id: string, config: DataCatalogEntryGroupConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _entryGroupId?;
    get entryGroupId(): string;
    set entryGroupId(value: string);
    get entryGroupIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    resetRegion(): void;
    get regionInput(): string | undefined;
    private _timeouts;
    get timeouts(): DataCatalogEntryGroupTimeoutsOutputReference;
    putTimeouts(value: DataCatalogEntryGroupTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | DataCatalogEntryGroupTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
