/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataplexAspectTypeConfig extends cdktf.TerraformMetaArguments {
    /**
    * The aspect type id of the aspect type.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/dataplex_aspect_type#aspect_type_id DataplexAspectType#aspect_type_id}
    */
    readonly aspectTypeId?: string;
    /**
    * Description of the AspectType.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/dataplex_aspect_type#description DataplexAspectType#description}
    */
    readonly description?: string;
    /**
    * User friendly display name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/dataplex_aspect_type#display_name DataplexAspectType#display_name}
    */
    readonly displayName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/dataplex_aspect_type#id DataplexAspectType#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * User-defined labels for the AspectType.
    *
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/dataplex_aspect_type#labels DataplexAspectType#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The location where aspect type will be created in.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/dataplex_aspect_type#location DataplexAspectType#location}
    */
    readonly location?: string;
    /**
    * MetadataTemplate of the Aspect.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/dataplex_aspect_type#metadata_template DataplexAspectType#metadata_template}
    */
    readonly metadataTemplate?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/dataplex_aspect_type#project DataplexAspectType#project}
    */
    readonly project?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/dataplex_aspect_type#timeouts DataplexAspectType#timeouts}
    */
    readonly timeouts?: DataplexAspectTypeTimeouts;
}
export interface DataplexAspectTypeTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/dataplex_aspect_type#create DataplexAspectType#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/dataplex_aspect_type#delete DataplexAspectType#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/dataplex_aspect_type#update DataplexAspectType#update}
    */
    readonly update?: string;
}
export declare function dataplexAspectTypeTimeoutsToTerraform(struct?: DataplexAspectTypeTimeouts | cdktf.IResolvable): any;
export declare function dataplexAspectTypeTimeoutsToHclTerraform(struct?: DataplexAspectTypeTimeouts | cdktf.IResolvable): any;
export declare class DataplexAspectTypeTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataplexAspectTypeTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: DataplexAspectTypeTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/dataplex_aspect_type google_dataplex_aspect_type}
*/
export declare class DataplexAspectType extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_dataplex_aspect_type";
    /**
    * Generates CDKTF code for importing a DataplexAspectType resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataplexAspectType to import
    * @param importFromId The id of the existing DataplexAspectType that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/dataplex_aspect_type#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataplexAspectType to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/dataplex_aspect_type google_dataplex_aspect_type} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataplexAspectTypeConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataplexAspectTypeConfig);
    private _aspectTypeId?;
    get aspectTypeId(): string;
    set aspectTypeId(value: string);
    resetAspectTypeId(): void;
    get aspectTypeIdInput(): string | undefined;
    get createTime(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    private _metadataTemplate?;
    get metadataTemplate(): string;
    set metadataTemplate(value: string);
    resetMetadataTemplate(): void;
    get metadataTemplateInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get transferStatus(): string;
    get uid(): string;
    get updateTime(): string;
    private _timeouts;
    get timeouts(): DataplexAspectTypeTimeoutsOutputReference;
    putTimeouts(value: DataplexAspectTypeTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | DataplexAspectTypeTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
