/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface EdgecontainerVpnConnectionConfig extends cdktf.TerraformMetaArguments {
    /**
    * The canonical Cluster name to connect to. It is in the form of projects/{project}/locations/{location}/clusters/{cluster}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/edgecontainer_vpn_connection#cluster EdgecontainerVpnConnection#cluster}
    */
    readonly cluster: string;
    /**
    * Whether this VPN connection has HA enabled on cluster side. If enabled, when creating VPN connection we will attempt to use 2 ANG floating IPs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/edgecontainer_vpn_connection#enable_high_availability EdgecontainerVpnConnection#enable_high_availability}
    */
    readonly enableHighAvailability?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/edgecontainer_vpn_connection#id EdgecontainerVpnConnection#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Labels associated with this resource.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/edgecontainer_vpn_connection#labels EdgecontainerVpnConnection#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Google Cloud Platform location.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/edgecontainer_vpn_connection#location EdgecontainerVpnConnection#location}
    */
    readonly location: string;
    /**
    * The resource name of VPN connection
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/edgecontainer_vpn_connection#name EdgecontainerVpnConnection#name}
    */
    readonly name: string;
    /**
    * NAT gateway IP, or WAN IP address. If a customer has multiple NAT IPs, the customer needs to configure NAT such that only one external IP maps to the GMEC Anthos cluster.
    * This is empty if NAT is not used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/edgecontainer_vpn_connection#nat_gateway_ip EdgecontainerVpnConnection#nat_gateway_ip}
    */
    readonly natGatewayIp?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/edgecontainer_vpn_connection#project EdgecontainerVpnConnection#project}
    */
    readonly project?: string;
    /**
    * The VPN connection Cloud Router name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/edgecontainer_vpn_connection#router EdgecontainerVpnConnection#router}
    */
    readonly router?: string;
    /**
    * The network ID of VPC to connect to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/edgecontainer_vpn_connection#vpc EdgecontainerVpnConnection#vpc}
    */
    readonly vpc?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/edgecontainer_vpn_connection#timeouts EdgecontainerVpnConnection#timeouts}
    */
    readonly timeouts?: EdgecontainerVpnConnectionTimeouts;
    /**
    * vpc_project block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/edgecontainer_vpn_connection#vpc_project EdgecontainerVpnConnection#vpc_project}
    */
    readonly vpcProject?: EdgecontainerVpnConnectionVpcProject;
}
export interface EdgecontainerVpnConnectionDetailsCloudRouter {
}
export declare function edgecontainerVpnConnectionDetailsCloudRouterToTerraform(struct?: EdgecontainerVpnConnectionDetailsCloudRouter): any;
export declare function edgecontainerVpnConnectionDetailsCloudRouterToHclTerraform(struct?: EdgecontainerVpnConnectionDetailsCloudRouter): any;
export declare class EdgecontainerVpnConnectionDetailsCloudRouterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): EdgecontainerVpnConnectionDetailsCloudRouter | undefined;
    set internalValue(value: EdgecontainerVpnConnectionDetailsCloudRouter | undefined);
    get name(): string;
}
export declare class EdgecontainerVpnConnectionDetailsCloudRouterList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): EdgecontainerVpnConnectionDetailsCloudRouterOutputReference;
}
export interface EdgecontainerVpnConnectionDetailsCloudVpns {
}
export declare function edgecontainerVpnConnectionDetailsCloudVpnsToTerraform(struct?: EdgecontainerVpnConnectionDetailsCloudVpns): any;
export declare function edgecontainerVpnConnectionDetailsCloudVpnsToHclTerraform(struct?: EdgecontainerVpnConnectionDetailsCloudVpns): any;
export declare class EdgecontainerVpnConnectionDetailsCloudVpnsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): EdgecontainerVpnConnectionDetailsCloudVpns | undefined;
    set internalValue(value: EdgecontainerVpnConnectionDetailsCloudVpns | undefined);
    get gateway(): string;
}
export declare class EdgecontainerVpnConnectionDetailsCloudVpnsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): EdgecontainerVpnConnectionDetailsCloudVpnsOutputReference;
}
export interface EdgecontainerVpnConnectionDetails {
}
export declare function edgecontainerVpnConnectionDetailsToTerraform(struct?: EdgecontainerVpnConnectionDetails): any;
export declare function edgecontainerVpnConnectionDetailsToHclTerraform(struct?: EdgecontainerVpnConnectionDetails): any;
export declare class EdgecontainerVpnConnectionDetailsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): EdgecontainerVpnConnectionDetails | undefined;
    set internalValue(value: EdgecontainerVpnConnectionDetails | undefined);
    private _cloudRouter;
    get cloudRouter(): EdgecontainerVpnConnectionDetailsCloudRouterList;
    private _cloudVpns;
    get cloudVpns(): EdgecontainerVpnConnectionDetailsCloudVpnsList;
    get error(): string;
    get state(): string;
}
export declare class EdgecontainerVpnConnectionDetailsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): EdgecontainerVpnConnectionDetailsOutputReference;
}
export interface EdgecontainerVpnConnectionTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/edgecontainer_vpn_connection#create EdgecontainerVpnConnection#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/edgecontainer_vpn_connection#delete EdgecontainerVpnConnection#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/edgecontainer_vpn_connection#update EdgecontainerVpnConnection#update}
    */
    readonly update?: string;
}
export declare function edgecontainerVpnConnectionTimeoutsToTerraform(struct?: EdgecontainerVpnConnectionTimeouts | cdktf.IResolvable): any;
export declare function edgecontainerVpnConnectionTimeoutsToHclTerraform(struct?: EdgecontainerVpnConnectionTimeouts | cdktf.IResolvable): any;
export declare class EdgecontainerVpnConnectionTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): EdgecontainerVpnConnectionTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: EdgecontainerVpnConnectionTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
export interface EdgecontainerVpnConnectionVpcProject {
    /**
    * The project of the VPC to connect to. If not specified, it is the same as the cluster project.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/edgecontainer_vpn_connection#project_id EdgecontainerVpnConnection#project_id}
    */
    readonly projectId?: string;
}
export declare function edgecontainerVpnConnectionVpcProjectToTerraform(struct?: EdgecontainerVpnConnectionVpcProjectOutputReference | EdgecontainerVpnConnectionVpcProject): any;
export declare function edgecontainerVpnConnectionVpcProjectToHclTerraform(struct?: EdgecontainerVpnConnectionVpcProjectOutputReference | EdgecontainerVpnConnectionVpcProject): any;
export declare class EdgecontainerVpnConnectionVpcProjectOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): EdgecontainerVpnConnectionVpcProject | undefined;
    set internalValue(value: EdgecontainerVpnConnectionVpcProject | undefined);
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/edgecontainer_vpn_connection google_edgecontainer_vpn_connection}
*/
export declare class EdgecontainerVpnConnection extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_edgecontainer_vpn_connection";
    /**
    * Generates CDKTF code for importing a EdgecontainerVpnConnection resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the EdgecontainerVpnConnection to import
    * @param importFromId The id of the existing EdgecontainerVpnConnection that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/edgecontainer_vpn_connection#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the EdgecontainerVpnConnection to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/edgecontainer_vpn_connection google_edgecontainer_vpn_connection} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options EdgecontainerVpnConnectionConfig
    */
    constructor(scope: Construct, id: string, config: EdgecontainerVpnConnectionConfig);
    private _cluster?;
    get cluster(): string;
    set cluster(value: string);
    get clusterInput(): string | undefined;
    get createTime(): string;
    private _details;
    get details(): EdgecontainerVpnConnectionDetailsList;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _enableHighAvailability?;
    get enableHighAvailability(): boolean | cdktf.IResolvable;
    set enableHighAvailability(value: boolean | cdktf.IResolvable);
    resetEnableHighAvailability(): void;
    get enableHighAvailabilityInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _natGatewayIp?;
    get natGatewayIp(): string;
    set natGatewayIp(value: string);
    resetNatGatewayIp(): void;
    get natGatewayIpInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _router?;
    get router(): string;
    set router(value: string);
    resetRouter(): void;
    get routerInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get updateTime(): string;
    private _vpc?;
    get vpc(): string;
    set vpc(value: string);
    resetVpc(): void;
    get vpcInput(): string | undefined;
    private _timeouts;
    get timeouts(): EdgecontainerVpnConnectionTimeoutsOutputReference;
    putTimeouts(value: EdgecontainerVpnConnectionTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | EdgecontainerVpnConnectionTimeouts | undefined;
    private _vpcProject;
    get vpcProject(): EdgecontainerVpnConnectionVpcProjectOutputReference;
    putVpcProject(value: EdgecontainerVpnConnectionVpcProject): void;
    resetVpcProject(): void;
    get vpcProjectInput(): EdgecontainerVpnConnectionVpcProject | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
