/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface IntegrationConnectorsConnectionConfig extends cdktf.TerraformMetaArguments {
    /**
    * connectorVersion of the Connector.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#connector_version IntegrationConnectorsConnection#connector_version}
    */
    readonly connectorVersion: string;
    /**
    * An arbitrary description for the Conection.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#description IntegrationConnectorsConnection#description}
    */
    readonly description?: string;
    /**
    * Eventing enablement type. Will be nil if eventing is not enabled. Possible values: ["EVENTING_AND_CONNECTION", "ONLY_EVENTING"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#eventing_enablement_type IntegrationConnectorsConnection#eventing_enablement_type}
    */
    readonly eventingEnablementType?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#id IntegrationConnectorsConnection#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Resource labels to represent user provided metadata.
    *
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#labels IntegrationConnectorsConnection#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Location in which Connection needs to be created.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#location IntegrationConnectorsConnection#location}
    */
    readonly location: string;
    /**
    * Name of Connection needs to be created.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#name IntegrationConnectorsConnection#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#project IntegrationConnectorsConnection#project}
    */
    readonly project?: string;
    /**
    * Service account needed for runtime plane to access Google Cloud resources.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#service_account IntegrationConnectorsConnection#service_account}
    */
    readonly serviceAccount?: string;
    /**
    * Suspended indicates if a user has suspended a connection or not.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#suspended IntegrationConnectorsConnection#suspended}
    */
    readonly suspended?: boolean | cdktf.IResolvable;
    /**
    * auth_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#auth_config IntegrationConnectorsConnection#auth_config}
    */
    readonly authConfig?: IntegrationConnectorsConnectionAuthConfig;
    /**
    * config_variable block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#config_variable IntegrationConnectorsConnection#config_variable}
    */
    readonly configVariable?: IntegrationConnectorsConnectionConfigVariable[] | cdktf.IResolvable;
    /**
    * destination_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#destination_config IntegrationConnectorsConnection#destination_config}
    */
    readonly destinationConfig?: IntegrationConnectorsConnectionDestinationConfig[] | cdktf.IResolvable;
    /**
    * eventing_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#eventing_config IntegrationConnectorsConnection#eventing_config}
    */
    readonly eventingConfig?: IntegrationConnectorsConnectionEventingConfig;
    /**
    * lock_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#lock_config IntegrationConnectorsConnection#lock_config}
    */
    readonly lockConfig?: IntegrationConnectorsConnectionLockConfig;
    /**
    * log_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#log_config IntegrationConnectorsConnection#log_config}
    */
    readonly logConfig?: IntegrationConnectorsConnectionLogConfig;
    /**
    * node_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#node_config IntegrationConnectorsConnection#node_config}
    */
    readonly nodeConfig?: IntegrationConnectorsConnectionNodeConfig;
    /**
    * ssl_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#ssl_config IntegrationConnectorsConnection#ssl_config}
    */
    readonly sslConfig?: IntegrationConnectorsConnectionSslConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#timeouts IntegrationConnectorsConnection#timeouts}
    */
    readonly timeouts?: IntegrationConnectorsConnectionTimeouts;
}
export interface IntegrationConnectorsConnectionConnectorVersionInfraConfig {
}
export declare function integrationConnectorsConnectionConnectorVersionInfraConfigToTerraform(struct?: IntegrationConnectorsConnectionConnectorVersionInfraConfig): any;
export declare function integrationConnectorsConnectionConnectorVersionInfraConfigToHclTerraform(struct?: IntegrationConnectorsConnectionConnectorVersionInfraConfig): any;
export declare class IntegrationConnectorsConnectionConnectorVersionInfraConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): IntegrationConnectorsConnectionConnectorVersionInfraConfig | undefined;
    set internalValue(value: IntegrationConnectorsConnectionConnectorVersionInfraConfig | undefined);
    get ratelimitThreshold(): string;
}
export declare class IntegrationConnectorsConnectionConnectorVersionInfraConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): IntegrationConnectorsConnectionConnectorVersionInfraConfigOutputReference;
}
export interface IntegrationConnectorsConnectionEventingRuntimeDataStatus {
}
export declare function integrationConnectorsConnectionEventingRuntimeDataStatusToTerraform(struct?: IntegrationConnectorsConnectionEventingRuntimeDataStatus): any;
export declare function integrationConnectorsConnectionEventingRuntimeDataStatusToHclTerraform(struct?: IntegrationConnectorsConnectionEventingRuntimeDataStatus): any;
export declare class IntegrationConnectorsConnectionEventingRuntimeDataStatusOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): IntegrationConnectorsConnectionEventingRuntimeDataStatus | undefined;
    set internalValue(value: IntegrationConnectorsConnectionEventingRuntimeDataStatus | undefined);
    get description(): string;
    get state(): string;
}
export declare class IntegrationConnectorsConnectionEventingRuntimeDataStatusList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): IntegrationConnectorsConnectionEventingRuntimeDataStatusOutputReference;
}
export interface IntegrationConnectorsConnectionEventingRuntimeData {
}
export declare function integrationConnectorsConnectionEventingRuntimeDataToTerraform(struct?: IntegrationConnectorsConnectionEventingRuntimeData): any;
export declare function integrationConnectorsConnectionEventingRuntimeDataToHclTerraform(struct?: IntegrationConnectorsConnectionEventingRuntimeData): any;
export declare class IntegrationConnectorsConnectionEventingRuntimeDataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): IntegrationConnectorsConnectionEventingRuntimeData | undefined;
    set internalValue(value: IntegrationConnectorsConnectionEventingRuntimeData | undefined);
    get eventsListenerEndpoint(): string;
    private _status;
    get status(): IntegrationConnectorsConnectionEventingRuntimeDataStatusList;
}
export declare class IntegrationConnectorsConnectionEventingRuntimeDataList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): IntegrationConnectorsConnectionEventingRuntimeDataOutputReference;
}
export interface IntegrationConnectorsConnectionStatus {
}
export declare function integrationConnectorsConnectionStatusToTerraform(struct?: IntegrationConnectorsConnectionStatus): any;
export declare function integrationConnectorsConnectionStatusToHclTerraform(struct?: IntegrationConnectorsConnectionStatus): any;
export declare class IntegrationConnectorsConnectionStatusOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): IntegrationConnectorsConnectionStatus | undefined;
    set internalValue(value: IntegrationConnectorsConnectionStatus | undefined);
    get description(): string;
    get state(): string;
    get status(): string;
}
export declare class IntegrationConnectorsConnectionStatusList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): IntegrationConnectorsConnectionStatusOutputReference;
}
export interface IntegrationConnectorsConnectionAuthConfigAdditionalVariableEncryptionKeyValue {
    /**
    * The [KMS key name] with which the content of the Operation is encrypted. The expected
    * format: projects/* /locations/* /keyRings/* /cryptoKeys/*.
    * Will be empty string if google managed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#kms_key_name IntegrationConnectorsConnection#kms_key_name}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly kmsKeyName?: string;
    /**
    * Type of Encription Key Possible values: ["GOOGLE_MANAGED", "CUSTOMER_MANAGED"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#type IntegrationConnectorsConnection#type}
    */
    readonly type: string;
}
export declare function integrationConnectorsConnectionAuthConfigAdditionalVariableEncryptionKeyValueToTerraform(struct?: IntegrationConnectorsConnectionAuthConfigAdditionalVariableEncryptionKeyValueOutputReference | IntegrationConnectorsConnectionAuthConfigAdditionalVariableEncryptionKeyValue): any;
export declare function integrationConnectorsConnectionAuthConfigAdditionalVariableEncryptionKeyValueToHclTerraform(struct?: IntegrationConnectorsConnectionAuthConfigAdditionalVariableEncryptionKeyValueOutputReference | IntegrationConnectorsConnectionAuthConfigAdditionalVariableEncryptionKeyValue): any;
export declare class IntegrationConnectorsConnectionAuthConfigAdditionalVariableEncryptionKeyValueOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionAuthConfigAdditionalVariableEncryptionKeyValue | undefined;
    set internalValue(value: IntegrationConnectorsConnectionAuthConfigAdditionalVariableEncryptionKeyValue | undefined);
    private _kmsKeyName?;
    get kmsKeyName(): string;
    set kmsKeyName(value: string);
    resetKmsKeyName(): void;
    get kmsKeyNameInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
}
export interface IntegrationConnectorsConnectionAuthConfigAdditionalVariableSecretValue {
    /**
    * Secret version of Secret Value for Config variable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#secret_version IntegrationConnectorsConnection#secret_version}
    */
    readonly secretVersion: string;
}
export declare function integrationConnectorsConnectionAuthConfigAdditionalVariableSecretValueToTerraform(struct?: IntegrationConnectorsConnectionAuthConfigAdditionalVariableSecretValueOutputReference | IntegrationConnectorsConnectionAuthConfigAdditionalVariableSecretValue): any;
export declare function integrationConnectorsConnectionAuthConfigAdditionalVariableSecretValueToHclTerraform(struct?: IntegrationConnectorsConnectionAuthConfigAdditionalVariableSecretValueOutputReference | IntegrationConnectorsConnectionAuthConfigAdditionalVariableSecretValue): any;
export declare class IntegrationConnectorsConnectionAuthConfigAdditionalVariableSecretValueOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionAuthConfigAdditionalVariableSecretValue | undefined;
    set internalValue(value: IntegrationConnectorsConnectionAuthConfigAdditionalVariableSecretValue | undefined);
    private _secretVersion?;
    get secretVersion(): string;
    set secretVersion(value: string);
    get secretVersionInput(): string | undefined;
}
export interface IntegrationConnectorsConnectionAuthConfigAdditionalVariable {
    /**
    * Boolean Value of configVariable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#boolean_value IntegrationConnectorsConnection#boolean_value}
    */
    readonly booleanValue?: boolean | cdktf.IResolvable;
    /**
    * Integer Value of configVariable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#integer_value IntegrationConnectorsConnection#integer_value}
    */
    readonly integerValue?: number;
    /**
    * Key for the configVariable
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#key IntegrationConnectorsConnection#key}
    */
    readonly key: string;
    /**
    * String Value of configVariabley.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#string_value IntegrationConnectorsConnection#string_value}
    */
    readonly stringValue?: string;
    /**
    * encryption_key_value block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#encryption_key_value IntegrationConnectorsConnection#encryption_key_value}
    */
    readonly encryptionKeyValue?: IntegrationConnectorsConnectionAuthConfigAdditionalVariableEncryptionKeyValue;
    /**
    * secret_value block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#secret_value IntegrationConnectorsConnection#secret_value}
    */
    readonly secretValue?: IntegrationConnectorsConnectionAuthConfigAdditionalVariableSecretValue;
}
export declare function integrationConnectorsConnectionAuthConfigAdditionalVariableToTerraform(struct?: IntegrationConnectorsConnectionAuthConfigAdditionalVariable | cdktf.IResolvable): any;
export declare function integrationConnectorsConnectionAuthConfigAdditionalVariableToHclTerraform(struct?: IntegrationConnectorsConnectionAuthConfigAdditionalVariable | cdktf.IResolvable): any;
export declare class IntegrationConnectorsConnectionAuthConfigAdditionalVariableOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): IntegrationConnectorsConnectionAuthConfigAdditionalVariable | cdktf.IResolvable | undefined;
    set internalValue(value: IntegrationConnectorsConnectionAuthConfigAdditionalVariable | cdktf.IResolvable | undefined);
    private _booleanValue?;
    get booleanValue(): boolean | cdktf.IResolvable;
    set booleanValue(value: boolean | cdktf.IResolvable);
    resetBooleanValue(): void;
    get booleanValueInput(): boolean | cdktf.IResolvable | undefined;
    private _integerValue?;
    get integerValue(): number;
    set integerValue(value: number);
    resetIntegerValue(): void;
    get integerValueInput(): number | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _stringValue?;
    get stringValue(): string;
    set stringValue(value: string);
    resetStringValue(): void;
    get stringValueInput(): string | undefined;
    private _encryptionKeyValue;
    get encryptionKeyValue(): IntegrationConnectorsConnectionAuthConfigAdditionalVariableEncryptionKeyValueOutputReference;
    putEncryptionKeyValue(value: IntegrationConnectorsConnectionAuthConfigAdditionalVariableEncryptionKeyValue): void;
    resetEncryptionKeyValue(): void;
    get encryptionKeyValueInput(): IntegrationConnectorsConnectionAuthConfigAdditionalVariableEncryptionKeyValue | undefined;
    private _secretValue;
    get secretValue(): IntegrationConnectorsConnectionAuthConfigAdditionalVariableSecretValueOutputReference;
    putSecretValue(value: IntegrationConnectorsConnectionAuthConfigAdditionalVariableSecretValue): void;
    resetSecretValue(): void;
    get secretValueInput(): IntegrationConnectorsConnectionAuthConfigAdditionalVariableSecretValue | undefined;
}
export declare class IntegrationConnectorsConnectionAuthConfigAdditionalVariableList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: IntegrationConnectorsConnectionAuthConfigAdditionalVariable[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): IntegrationConnectorsConnectionAuthConfigAdditionalVariableOutputReference;
}
export interface IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlowClientSecret {
    /**
    * The resource name of the secret version in the format,
    * format as: projects/* /secrets/* /versions/*.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#secret_version IntegrationConnectorsConnection#secret_version}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly secretVersion: string;
}
export declare function integrationConnectorsConnectionAuthConfigOauth2AuthCodeFlowClientSecretToTerraform(struct?: IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlowClientSecretOutputReference | IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlowClientSecret): any;
export declare function integrationConnectorsConnectionAuthConfigOauth2AuthCodeFlowClientSecretToHclTerraform(struct?: IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlowClientSecretOutputReference | IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlowClientSecret): any;
export declare class IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlowClientSecretOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlowClientSecret | undefined;
    set internalValue(value: IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlowClientSecret | undefined);
    private _secretVersion?;
    get secretVersion(): string;
    set secretVersion(value: string);
    get secretVersionInput(): string | undefined;
}
export interface IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlow {
    /**
    * Auth URL for Authorization Code Flow.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#auth_uri IntegrationConnectorsConnection#auth_uri}
    */
    readonly authUri?: string;
    /**
    * Client ID for user-provided OAuth app.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#client_id IntegrationConnectorsConnection#client_id}
    */
    readonly clientId?: string;
    /**
    * Whether to enable PKCE when the user performs the auth code flow.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#enable_pkce IntegrationConnectorsConnection#enable_pkce}
    */
    readonly enablePkce?: boolean | cdktf.IResolvable;
    /**
    * Scopes the connection will request when the user performs the auth code flow.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#scopes IntegrationConnectorsConnection#scopes}
    */
    readonly scopes?: string[];
    /**
    * client_secret block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#client_secret IntegrationConnectorsConnection#client_secret}
    */
    readonly clientSecret?: IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlowClientSecret;
}
export declare function integrationConnectorsConnectionAuthConfigOauth2AuthCodeFlowToTerraform(struct?: IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlowOutputReference | IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlow): any;
export declare function integrationConnectorsConnectionAuthConfigOauth2AuthCodeFlowToHclTerraform(struct?: IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlowOutputReference | IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlow): any;
export declare class IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlowOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlow | undefined;
    set internalValue(value: IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlow | undefined);
    private _authUri?;
    get authUri(): string;
    set authUri(value: string);
    resetAuthUri(): void;
    get authUriInput(): string | undefined;
    private _clientId?;
    get clientId(): string;
    set clientId(value: string);
    resetClientId(): void;
    get clientIdInput(): string | undefined;
    private _enablePkce?;
    get enablePkce(): boolean | cdktf.IResolvable;
    set enablePkce(value: boolean | cdktf.IResolvable);
    resetEnablePkce(): void;
    get enablePkceInput(): boolean | cdktf.IResolvable | undefined;
    private _scopes?;
    get scopes(): string[];
    set scopes(value: string[]);
    resetScopes(): void;
    get scopesInput(): string[] | undefined;
    private _clientSecret;
    get clientSecret(): IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlowClientSecretOutputReference;
    putClientSecret(value: IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlowClientSecret): void;
    resetClientSecret(): void;
    get clientSecretInput(): IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlowClientSecret | undefined;
}
export interface IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentialsClientSecret {
    /**
    * The resource name of the secret version in the format,
    * format as: projects/* /secrets/* /versions/*.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#secret_version IntegrationConnectorsConnection#secret_version}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly secretVersion: string;
}
export declare function integrationConnectorsConnectionAuthConfigOauth2ClientCredentialsClientSecretToTerraform(struct?: IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentialsClientSecretOutputReference | IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentialsClientSecret): any;
export declare function integrationConnectorsConnectionAuthConfigOauth2ClientCredentialsClientSecretToHclTerraform(struct?: IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentialsClientSecretOutputReference | IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentialsClientSecret): any;
export declare class IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentialsClientSecretOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentialsClientSecret | undefined;
    set internalValue(value: IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentialsClientSecret | undefined);
    private _secretVersion?;
    get secretVersion(): string;
    set secretVersion(value: string);
    get secretVersionInput(): string | undefined;
}
export interface IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentials {
    /**
    * Secret version of Password for Authentication.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#client_id IntegrationConnectorsConnection#client_id}
    */
    readonly clientId: string;
    /**
    * client_secret block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#client_secret IntegrationConnectorsConnection#client_secret}
    */
    readonly clientSecret?: IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentialsClientSecret;
}
export declare function integrationConnectorsConnectionAuthConfigOauth2ClientCredentialsToTerraform(struct?: IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentialsOutputReference | IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentials): any;
export declare function integrationConnectorsConnectionAuthConfigOauth2ClientCredentialsToHclTerraform(struct?: IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentialsOutputReference | IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentials): any;
export declare class IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentialsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentials | undefined;
    set internalValue(value: IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentials | undefined);
    private _clientId?;
    get clientId(): string;
    set clientId(value: string);
    get clientIdInput(): string | undefined;
    private _clientSecret;
    get clientSecret(): IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentialsClientSecretOutputReference;
    putClientSecret(value: IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentialsClientSecret): void;
    resetClientSecret(): void;
    get clientSecretInput(): IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentialsClientSecret | undefined;
}
export interface IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerClientKey {
    /**
    * The resource name of the secret version in the format,
    * format as: projects/* /secrets/* /versions/*.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#secret_version IntegrationConnectorsConnection#secret_version}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly secretVersion: string;
}
export declare function integrationConnectorsConnectionAuthConfigOauth2JwtBearerClientKeyToTerraform(struct?: IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerClientKeyOutputReference | IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerClientKey): any;
export declare function integrationConnectorsConnectionAuthConfigOauth2JwtBearerClientKeyToHclTerraform(struct?: IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerClientKeyOutputReference | IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerClientKey): any;
export declare class IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerClientKeyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerClientKey | undefined;
    set internalValue(value: IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerClientKey | undefined);
    private _secretVersion?;
    get secretVersion(): string;
    set secretVersion(value: string);
    get secretVersionInput(): string | undefined;
}
export interface IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerJwtClaims {
    /**
    * Value for the "aud" claim.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#audience IntegrationConnectorsConnection#audience}
    */
    readonly audience?: string;
    /**
    * Value for the "iss" claim.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#issuer IntegrationConnectorsConnection#issuer}
    */
    readonly issuer?: string;
    /**
    * Value for the "sub" claim.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#subject IntegrationConnectorsConnection#subject}
    */
    readonly subject?: string;
}
export declare function integrationConnectorsConnectionAuthConfigOauth2JwtBearerJwtClaimsToTerraform(struct?: IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerJwtClaimsOutputReference | IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerJwtClaims): any;
export declare function integrationConnectorsConnectionAuthConfigOauth2JwtBearerJwtClaimsToHclTerraform(struct?: IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerJwtClaimsOutputReference | IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerJwtClaims): any;
export declare class IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerJwtClaimsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerJwtClaims | undefined;
    set internalValue(value: IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerJwtClaims | undefined);
    private _audience?;
    get audience(): string;
    set audience(value: string);
    resetAudience(): void;
    get audienceInput(): string | undefined;
    private _issuer?;
    get issuer(): string;
    set issuer(value: string);
    resetIssuer(): void;
    get issuerInput(): string | undefined;
    private _subject?;
    get subject(): string;
    set subject(value: string);
    resetSubject(): void;
    get subjectInput(): string | undefined;
}
export interface IntegrationConnectorsConnectionAuthConfigOauth2JwtBearer {
    /**
    * client_key block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#client_key IntegrationConnectorsConnection#client_key}
    */
    readonly clientKey?: IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerClientKey;
    /**
    * jwt_claims block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#jwt_claims IntegrationConnectorsConnection#jwt_claims}
    */
    readonly jwtClaims?: IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerJwtClaims;
}
export declare function integrationConnectorsConnectionAuthConfigOauth2JwtBearerToTerraform(struct?: IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerOutputReference | IntegrationConnectorsConnectionAuthConfigOauth2JwtBearer): any;
export declare function integrationConnectorsConnectionAuthConfigOauth2JwtBearerToHclTerraform(struct?: IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerOutputReference | IntegrationConnectorsConnectionAuthConfigOauth2JwtBearer): any;
export declare class IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionAuthConfigOauth2JwtBearer | undefined;
    set internalValue(value: IntegrationConnectorsConnectionAuthConfigOauth2JwtBearer | undefined);
    private _clientKey;
    get clientKey(): IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerClientKeyOutputReference;
    putClientKey(value: IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerClientKey): void;
    resetClientKey(): void;
    get clientKeyInput(): IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerClientKey | undefined;
    private _jwtClaims;
    get jwtClaims(): IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerJwtClaimsOutputReference;
    putJwtClaims(value: IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerJwtClaims): void;
    resetJwtClaims(): void;
    get jwtClaimsInput(): IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerJwtClaims | undefined;
}
export interface IntegrationConnectorsConnectionAuthConfigSshPublicKeySshClientCert {
    /**
    * The resource name of the secret version in the format,
    * format as: projects/* /secrets/* /versions/*.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#secret_version IntegrationConnectorsConnection#secret_version}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly secretVersion: string;
}
export declare function integrationConnectorsConnectionAuthConfigSshPublicKeySshClientCertToTerraform(struct?: IntegrationConnectorsConnectionAuthConfigSshPublicKeySshClientCertOutputReference | IntegrationConnectorsConnectionAuthConfigSshPublicKeySshClientCert): any;
export declare function integrationConnectorsConnectionAuthConfigSshPublicKeySshClientCertToHclTerraform(struct?: IntegrationConnectorsConnectionAuthConfigSshPublicKeySshClientCertOutputReference | IntegrationConnectorsConnectionAuthConfigSshPublicKeySshClientCert): any;
export declare class IntegrationConnectorsConnectionAuthConfigSshPublicKeySshClientCertOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionAuthConfigSshPublicKeySshClientCert | undefined;
    set internalValue(value: IntegrationConnectorsConnectionAuthConfigSshPublicKeySshClientCert | undefined);
    private _secretVersion?;
    get secretVersion(): string;
    set secretVersion(value: string);
    get secretVersionInput(): string | undefined;
}
export interface IntegrationConnectorsConnectionAuthConfigSshPublicKeySshClientCertPass {
    /**
    * The resource name of the secret version in the format,
    * format as: projects/* /secrets/* /versions/*.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#secret_version IntegrationConnectorsConnection#secret_version}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly secretVersion: string;
}
export declare function integrationConnectorsConnectionAuthConfigSshPublicKeySshClientCertPassToTerraform(struct?: IntegrationConnectorsConnectionAuthConfigSshPublicKeySshClientCertPassOutputReference | IntegrationConnectorsConnectionAuthConfigSshPublicKeySshClientCertPass): any;
export declare function integrationConnectorsConnectionAuthConfigSshPublicKeySshClientCertPassToHclTerraform(struct?: IntegrationConnectorsConnectionAuthConfigSshPublicKeySshClientCertPassOutputReference | IntegrationConnectorsConnectionAuthConfigSshPublicKeySshClientCertPass): any;
export declare class IntegrationConnectorsConnectionAuthConfigSshPublicKeySshClientCertPassOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionAuthConfigSshPublicKeySshClientCertPass | undefined;
    set internalValue(value: IntegrationConnectorsConnectionAuthConfigSshPublicKeySshClientCertPass | undefined);
    private _secretVersion?;
    get secretVersion(): string;
    set secretVersion(value: string);
    get secretVersionInput(): string | undefined;
}
export interface IntegrationConnectorsConnectionAuthConfigSshPublicKey {
    /**
    * Format of SSH Client cert.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#cert_type IntegrationConnectorsConnection#cert_type}
    */
    readonly certType?: string;
    /**
    * The user account used to authenticate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#username IntegrationConnectorsConnection#username}
    */
    readonly username: string;
    /**
    * ssh_client_cert block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#ssh_client_cert IntegrationConnectorsConnection#ssh_client_cert}
    */
    readonly sshClientCert?: IntegrationConnectorsConnectionAuthConfigSshPublicKeySshClientCert;
    /**
    * ssh_client_cert_pass block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#ssh_client_cert_pass IntegrationConnectorsConnection#ssh_client_cert_pass}
    */
    readonly sshClientCertPass?: IntegrationConnectorsConnectionAuthConfigSshPublicKeySshClientCertPass;
}
export declare function integrationConnectorsConnectionAuthConfigSshPublicKeyToTerraform(struct?: IntegrationConnectorsConnectionAuthConfigSshPublicKeyOutputReference | IntegrationConnectorsConnectionAuthConfigSshPublicKey): any;
export declare function integrationConnectorsConnectionAuthConfigSshPublicKeyToHclTerraform(struct?: IntegrationConnectorsConnectionAuthConfigSshPublicKeyOutputReference | IntegrationConnectorsConnectionAuthConfigSshPublicKey): any;
export declare class IntegrationConnectorsConnectionAuthConfigSshPublicKeyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionAuthConfigSshPublicKey | undefined;
    set internalValue(value: IntegrationConnectorsConnectionAuthConfigSshPublicKey | undefined);
    private _certType?;
    get certType(): string;
    set certType(value: string);
    resetCertType(): void;
    get certTypeInput(): string | undefined;
    private _username?;
    get username(): string;
    set username(value: string);
    get usernameInput(): string | undefined;
    private _sshClientCert;
    get sshClientCert(): IntegrationConnectorsConnectionAuthConfigSshPublicKeySshClientCertOutputReference;
    putSshClientCert(value: IntegrationConnectorsConnectionAuthConfigSshPublicKeySshClientCert): void;
    resetSshClientCert(): void;
    get sshClientCertInput(): IntegrationConnectorsConnectionAuthConfigSshPublicKeySshClientCert | undefined;
    private _sshClientCertPass;
    get sshClientCertPass(): IntegrationConnectorsConnectionAuthConfigSshPublicKeySshClientCertPassOutputReference;
    putSshClientCertPass(value: IntegrationConnectorsConnectionAuthConfigSshPublicKeySshClientCertPass): void;
    resetSshClientCertPass(): void;
    get sshClientCertPassInput(): IntegrationConnectorsConnectionAuthConfigSshPublicKeySshClientCertPass | undefined;
}
export interface IntegrationConnectorsConnectionAuthConfigUserPasswordPassword {
    /**
    * The resource name of the secret version in the format,
    * format as: projects/* /secrets/* /versions/*.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#secret_version IntegrationConnectorsConnection#secret_version}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly secretVersion: string;
}
export declare function integrationConnectorsConnectionAuthConfigUserPasswordPasswordToTerraform(struct?: IntegrationConnectorsConnectionAuthConfigUserPasswordPasswordOutputReference | IntegrationConnectorsConnectionAuthConfigUserPasswordPassword): any;
export declare function integrationConnectorsConnectionAuthConfigUserPasswordPasswordToHclTerraform(struct?: IntegrationConnectorsConnectionAuthConfigUserPasswordPasswordOutputReference | IntegrationConnectorsConnectionAuthConfigUserPasswordPassword): any;
export declare class IntegrationConnectorsConnectionAuthConfigUserPasswordPasswordOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionAuthConfigUserPasswordPassword | undefined;
    set internalValue(value: IntegrationConnectorsConnectionAuthConfigUserPasswordPassword | undefined);
    private _secretVersion?;
    get secretVersion(): string;
    set secretVersion(value: string);
    get secretVersionInput(): string | undefined;
}
export interface IntegrationConnectorsConnectionAuthConfigUserPassword {
    /**
    * Username for Authentication.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#username IntegrationConnectorsConnection#username}
    */
    readonly username: string;
    /**
    * password block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#password IntegrationConnectorsConnection#password}
    */
    readonly password?: IntegrationConnectorsConnectionAuthConfigUserPasswordPassword;
}
export declare function integrationConnectorsConnectionAuthConfigUserPasswordToTerraform(struct?: IntegrationConnectorsConnectionAuthConfigUserPasswordOutputReference | IntegrationConnectorsConnectionAuthConfigUserPassword): any;
export declare function integrationConnectorsConnectionAuthConfigUserPasswordToHclTerraform(struct?: IntegrationConnectorsConnectionAuthConfigUserPasswordOutputReference | IntegrationConnectorsConnectionAuthConfigUserPassword): any;
export declare class IntegrationConnectorsConnectionAuthConfigUserPasswordOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionAuthConfigUserPassword | undefined;
    set internalValue(value: IntegrationConnectorsConnectionAuthConfigUserPassword | undefined);
    private _username?;
    get username(): string;
    set username(value: string);
    get usernameInput(): string | undefined;
    private _password;
    get password(): IntegrationConnectorsConnectionAuthConfigUserPasswordPasswordOutputReference;
    putPassword(value: IntegrationConnectorsConnectionAuthConfigUserPasswordPassword): void;
    resetPassword(): void;
    get passwordInput(): IntegrationConnectorsConnectionAuthConfigUserPasswordPassword | undefined;
}
export interface IntegrationConnectorsConnectionAuthConfig {
    /**
    * The type of authentication configured.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#auth_key IntegrationConnectorsConnection#auth_key}
    */
    readonly authKey?: string;
    /**
    * authType of the Connection Possible values: ["USER_PASSWORD", "OAUTH2_JWT_BEARER", "OAUTH2_CLIENT_CREDENTIALS", "SSH_PUBLIC_KEY", "OAUTH2_AUTH_CODE_FLOW"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#auth_type IntegrationConnectorsConnection#auth_type}
    */
    readonly authType: string;
    /**
    * additional_variable block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#additional_variable IntegrationConnectorsConnection#additional_variable}
    */
    readonly additionalVariable?: IntegrationConnectorsConnectionAuthConfigAdditionalVariable[] | cdktf.IResolvable;
    /**
    * oauth2_auth_code_flow block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#oauth2_auth_code_flow IntegrationConnectorsConnection#oauth2_auth_code_flow}
    */
    readonly oauth2AuthCodeFlow?: IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlow;
    /**
    * oauth2_client_credentials block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#oauth2_client_credentials IntegrationConnectorsConnection#oauth2_client_credentials}
    */
    readonly oauth2ClientCredentials?: IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentials;
    /**
    * oauth2_jwt_bearer block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#oauth2_jwt_bearer IntegrationConnectorsConnection#oauth2_jwt_bearer}
    */
    readonly oauth2JwtBearer?: IntegrationConnectorsConnectionAuthConfigOauth2JwtBearer;
    /**
    * ssh_public_key block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#ssh_public_key IntegrationConnectorsConnection#ssh_public_key}
    */
    readonly sshPublicKey?: IntegrationConnectorsConnectionAuthConfigSshPublicKey;
    /**
    * user_password block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#user_password IntegrationConnectorsConnection#user_password}
    */
    readonly userPassword?: IntegrationConnectorsConnectionAuthConfigUserPassword;
}
export declare function integrationConnectorsConnectionAuthConfigToTerraform(struct?: IntegrationConnectorsConnectionAuthConfigOutputReference | IntegrationConnectorsConnectionAuthConfig): any;
export declare function integrationConnectorsConnectionAuthConfigToHclTerraform(struct?: IntegrationConnectorsConnectionAuthConfigOutputReference | IntegrationConnectorsConnectionAuthConfig): any;
export declare class IntegrationConnectorsConnectionAuthConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionAuthConfig | undefined;
    set internalValue(value: IntegrationConnectorsConnectionAuthConfig | undefined);
    private _authKey?;
    get authKey(): string;
    set authKey(value: string);
    resetAuthKey(): void;
    get authKeyInput(): string | undefined;
    private _authType?;
    get authType(): string;
    set authType(value: string);
    get authTypeInput(): string | undefined;
    private _additionalVariable;
    get additionalVariable(): IntegrationConnectorsConnectionAuthConfigAdditionalVariableList;
    putAdditionalVariable(value: IntegrationConnectorsConnectionAuthConfigAdditionalVariable[] | cdktf.IResolvable): void;
    resetAdditionalVariable(): void;
    get additionalVariableInput(): cdktf.IResolvable | IntegrationConnectorsConnectionAuthConfigAdditionalVariable[] | undefined;
    private _oauth2AuthCodeFlow;
    get oauth2AuthCodeFlow(): IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlowOutputReference;
    putOauth2AuthCodeFlow(value: IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlow): void;
    resetOauth2AuthCodeFlow(): void;
    get oauth2AuthCodeFlowInput(): IntegrationConnectorsConnectionAuthConfigOauth2AuthCodeFlow | undefined;
    private _oauth2ClientCredentials;
    get oauth2ClientCredentials(): IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentialsOutputReference;
    putOauth2ClientCredentials(value: IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentials): void;
    resetOauth2ClientCredentials(): void;
    get oauth2ClientCredentialsInput(): IntegrationConnectorsConnectionAuthConfigOauth2ClientCredentials | undefined;
    private _oauth2JwtBearer;
    get oauth2JwtBearer(): IntegrationConnectorsConnectionAuthConfigOauth2JwtBearerOutputReference;
    putOauth2JwtBearer(value: IntegrationConnectorsConnectionAuthConfigOauth2JwtBearer): void;
    resetOauth2JwtBearer(): void;
    get oauth2JwtBearerInput(): IntegrationConnectorsConnectionAuthConfigOauth2JwtBearer | undefined;
    private _sshPublicKey;
    get sshPublicKey(): IntegrationConnectorsConnectionAuthConfigSshPublicKeyOutputReference;
    putSshPublicKey(value: IntegrationConnectorsConnectionAuthConfigSshPublicKey): void;
    resetSshPublicKey(): void;
    get sshPublicKeyInput(): IntegrationConnectorsConnectionAuthConfigSshPublicKey | undefined;
    private _userPassword;
    get userPassword(): IntegrationConnectorsConnectionAuthConfigUserPasswordOutputReference;
    putUserPassword(value: IntegrationConnectorsConnectionAuthConfigUserPassword): void;
    resetUserPassword(): void;
    get userPasswordInput(): IntegrationConnectorsConnectionAuthConfigUserPassword | undefined;
}
export interface IntegrationConnectorsConnectionConfigVariableEncryptionKeyValue {
    /**
    * The [KMS key name] with which the content of the Operation is encrypted. The expected
    * format: projects/* /locations/* /keyRings/* /cryptoKeys/*.
    * Will be empty string if google managed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#kms_key_name IntegrationConnectorsConnection#kms_key_name}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly kmsKeyName?: string;
    /**
    * Type of Encription Key Possible values: ["GOOGLE_MANAGED", "CUSTOMER_MANAGED"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#type IntegrationConnectorsConnection#type}
    */
    readonly type: string;
}
export declare function integrationConnectorsConnectionConfigVariableEncryptionKeyValueToTerraform(struct?: IntegrationConnectorsConnectionConfigVariableEncryptionKeyValueOutputReference | IntegrationConnectorsConnectionConfigVariableEncryptionKeyValue): any;
export declare function integrationConnectorsConnectionConfigVariableEncryptionKeyValueToHclTerraform(struct?: IntegrationConnectorsConnectionConfigVariableEncryptionKeyValueOutputReference | IntegrationConnectorsConnectionConfigVariableEncryptionKeyValue): any;
export declare class IntegrationConnectorsConnectionConfigVariableEncryptionKeyValueOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionConfigVariableEncryptionKeyValue | undefined;
    set internalValue(value: IntegrationConnectorsConnectionConfigVariableEncryptionKeyValue | undefined);
    private _kmsKeyName?;
    get kmsKeyName(): string;
    set kmsKeyName(value: string);
    resetKmsKeyName(): void;
    get kmsKeyNameInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
}
export interface IntegrationConnectorsConnectionConfigVariableSecretValue {
    /**
    * Secret version of Secret Value for Config variable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#secret_version IntegrationConnectorsConnection#secret_version}
    */
    readonly secretVersion: string;
}
export declare function integrationConnectorsConnectionConfigVariableSecretValueToTerraform(struct?: IntegrationConnectorsConnectionConfigVariableSecretValueOutputReference | IntegrationConnectorsConnectionConfigVariableSecretValue): any;
export declare function integrationConnectorsConnectionConfigVariableSecretValueToHclTerraform(struct?: IntegrationConnectorsConnectionConfigVariableSecretValueOutputReference | IntegrationConnectorsConnectionConfigVariableSecretValue): any;
export declare class IntegrationConnectorsConnectionConfigVariableSecretValueOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionConfigVariableSecretValue | undefined;
    set internalValue(value: IntegrationConnectorsConnectionConfigVariableSecretValue | undefined);
    private _secretVersion?;
    get secretVersion(): string;
    set secretVersion(value: string);
    get secretVersionInput(): string | undefined;
}
export interface IntegrationConnectorsConnectionConfigVariable {
    /**
    * Boolean Value of configVariable
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#boolean_value IntegrationConnectorsConnection#boolean_value}
    */
    readonly booleanValue?: boolean | cdktf.IResolvable;
    /**
    * Integer Value of configVariable
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#integer_value IntegrationConnectorsConnection#integer_value}
    */
    readonly integerValue?: number;
    /**
    * Key for the configVariable
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#key IntegrationConnectorsConnection#key}
    */
    readonly key: string;
    /**
    * String Value of configVariabley
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#string_value IntegrationConnectorsConnection#string_value}
    */
    readonly stringValue?: string;
    /**
    * encryption_key_value block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#encryption_key_value IntegrationConnectorsConnection#encryption_key_value}
    */
    readonly encryptionKeyValue?: IntegrationConnectorsConnectionConfigVariableEncryptionKeyValue;
    /**
    * secret_value block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#secret_value IntegrationConnectorsConnection#secret_value}
    */
    readonly secretValue?: IntegrationConnectorsConnectionConfigVariableSecretValue;
}
export declare function integrationConnectorsConnectionConfigVariableToTerraform(struct?: IntegrationConnectorsConnectionConfigVariable | cdktf.IResolvable): any;
export declare function integrationConnectorsConnectionConfigVariableToHclTerraform(struct?: IntegrationConnectorsConnectionConfigVariable | cdktf.IResolvable): any;
export declare class IntegrationConnectorsConnectionConfigVariableOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): IntegrationConnectorsConnectionConfigVariable | cdktf.IResolvable | undefined;
    set internalValue(value: IntegrationConnectorsConnectionConfigVariable | cdktf.IResolvable | undefined);
    private _booleanValue?;
    get booleanValue(): boolean | cdktf.IResolvable;
    set booleanValue(value: boolean | cdktf.IResolvable);
    resetBooleanValue(): void;
    get booleanValueInput(): boolean | cdktf.IResolvable | undefined;
    private _integerValue?;
    get integerValue(): number;
    set integerValue(value: number);
    resetIntegerValue(): void;
    get integerValueInput(): number | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _stringValue?;
    get stringValue(): string;
    set stringValue(value: string);
    resetStringValue(): void;
    get stringValueInput(): string | undefined;
    private _encryptionKeyValue;
    get encryptionKeyValue(): IntegrationConnectorsConnectionConfigVariableEncryptionKeyValueOutputReference;
    putEncryptionKeyValue(value: IntegrationConnectorsConnectionConfigVariableEncryptionKeyValue): void;
    resetEncryptionKeyValue(): void;
    get encryptionKeyValueInput(): IntegrationConnectorsConnectionConfigVariableEncryptionKeyValue | undefined;
    private _secretValue;
    get secretValue(): IntegrationConnectorsConnectionConfigVariableSecretValueOutputReference;
    putSecretValue(value: IntegrationConnectorsConnectionConfigVariableSecretValue): void;
    resetSecretValue(): void;
    get secretValueInput(): IntegrationConnectorsConnectionConfigVariableSecretValue | undefined;
}
export declare class IntegrationConnectorsConnectionConfigVariableList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: IntegrationConnectorsConnectionConfigVariable[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): IntegrationConnectorsConnectionConfigVariableOutputReference;
}
export interface IntegrationConnectorsConnectionDestinationConfigDestination {
    /**
    * For publicly routable host.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#host IntegrationConnectorsConnection#host}
    */
    readonly host?: string;
    /**
    * The port is the target port number that is accepted by the destination.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#port IntegrationConnectorsConnection#port}
    */
    readonly port?: number;
    /**
    * PSC service attachments. Format: projects/* /regions/* /serviceAttachments/*
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#service_attachment IntegrationConnectorsConnection#service_attachment}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly serviceAttachment?: string;
}
export declare function integrationConnectorsConnectionDestinationConfigDestinationToTerraform(struct?: IntegrationConnectorsConnectionDestinationConfigDestination | cdktf.IResolvable): any;
export declare function integrationConnectorsConnectionDestinationConfigDestinationToHclTerraform(struct?: IntegrationConnectorsConnectionDestinationConfigDestination | cdktf.IResolvable): any;
export declare class IntegrationConnectorsConnectionDestinationConfigDestinationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): IntegrationConnectorsConnectionDestinationConfigDestination | cdktf.IResolvable | undefined;
    set internalValue(value: IntegrationConnectorsConnectionDestinationConfigDestination | cdktf.IResolvable | undefined);
    private _host?;
    get host(): string;
    set host(value: string);
    resetHost(): void;
    get hostInput(): string | undefined;
    private _port?;
    get port(): number;
    set port(value: number);
    resetPort(): void;
    get portInput(): number | undefined;
    private _serviceAttachment?;
    get serviceAttachment(): string;
    set serviceAttachment(value: string);
    resetServiceAttachment(): void;
    get serviceAttachmentInput(): string | undefined;
}
export declare class IntegrationConnectorsConnectionDestinationConfigDestinationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: IntegrationConnectorsConnectionDestinationConfigDestination[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): IntegrationConnectorsConnectionDestinationConfigDestinationOutputReference;
}
export interface IntegrationConnectorsConnectionDestinationConfig {
    /**
    * The key is the destination identifier that is supported by the Connector.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#key IntegrationConnectorsConnection#key}
    */
    readonly key: string;
    /**
    * destination block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#destination IntegrationConnectorsConnection#destination}
    */
    readonly destination?: IntegrationConnectorsConnectionDestinationConfigDestination[] | cdktf.IResolvable;
}
export declare function integrationConnectorsConnectionDestinationConfigToTerraform(struct?: IntegrationConnectorsConnectionDestinationConfig | cdktf.IResolvable): any;
export declare function integrationConnectorsConnectionDestinationConfigToHclTerraform(struct?: IntegrationConnectorsConnectionDestinationConfig | cdktf.IResolvable): any;
export declare class IntegrationConnectorsConnectionDestinationConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): IntegrationConnectorsConnectionDestinationConfig | cdktf.IResolvable | undefined;
    set internalValue(value: IntegrationConnectorsConnectionDestinationConfig | cdktf.IResolvable | undefined);
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _destination;
    get destination(): IntegrationConnectorsConnectionDestinationConfigDestinationList;
    putDestination(value: IntegrationConnectorsConnectionDestinationConfigDestination[] | cdktf.IResolvable): void;
    resetDestination(): void;
    get destinationInput(): cdktf.IResolvable | IntegrationConnectorsConnectionDestinationConfigDestination[] | undefined;
}
export declare class IntegrationConnectorsConnectionDestinationConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: IntegrationConnectorsConnectionDestinationConfig[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): IntegrationConnectorsConnectionDestinationConfigOutputReference;
}
export interface IntegrationConnectorsConnectionEventingConfigAdditionalVariableEncryptionKeyValue {
    /**
    * The [KMS key name] with which the content of the Operation is encrypted. The expected
    * format: projects/* /locations/* /keyRings/* /cryptoKeys/*.
    * Will be empty string if google managed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#kms_key_name IntegrationConnectorsConnection#kms_key_name}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly kmsKeyName?: string;
    /**
    * Type of Encryption Key Possible values: ["GOOGLE_MANAGED", "CUSTOMER_MANAGED"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#type IntegrationConnectorsConnection#type}
    */
    readonly type?: string;
}
export declare function integrationConnectorsConnectionEventingConfigAdditionalVariableEncryptionKeyValueToTerraform(struct?: IntegrationConnectorsConnectionEventingConfigAdditionalVariableEncryptionKeyValueOutputReference | IntegrationConnectorsConnectionEventingConfigAdditionalVariableEncryptionKeyValue): any;
export declare function integrationConnectorsConnectionEventingConfigAdditionalVariableEncryptionKeyValueToHclTerraform(struct?: IntegrationConnectorsConnectionEventingConfigAdditionalVariableEncryptionKeyValueOutputReference | IntegrationConnectorsConnectionEventingConfigAdditionalVariableEncryptionKeyValue): any;
export declare class IntegrationConnectorsConnectionEventingConfigAdditionalVariableEncryptionKeyValueOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionEventingConfigAdditionalVariableEncryptionKeyValue | undefined;
    set internalValue(value: IntegrationConnectorsConnectionEventingConfigAdditionalVariableEncryptionKeyValue | undefined);
    private _kmsKeyName?;
    get kmsKeyName(): string;
    set kmsKeyName(value: string);
    resetKmsKeyName(): void;
    get kmsKeyNameInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
}
export interface IntegrationConnectorsConnectionEventingConfigAdditionalVariableSecretValue {
    /**
    * Secret version of Secret Value for Config variable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#secret_version IntegrationConnectorsConnection#secret_version}
    */
    readonly secretVersion: string;
}
export declare function integrationConnectorsConnectionEventingConfigAdditionalVariableSecretValueToTerraform(struct?: IntegrationConnectorsConnectionEventingConfigAdditionalVariableSecretValueOutputReference | IntegrationConnectorsConnectionEventingConfigAdditionalVariableSecretValue): any;
export declare function integrationConnectorsConnectionEventingConfigAdditionalVariableSecretValueToHclTerraform(struct?: IntegrationConnectorsConnectionEventingConfigAdditionalVariableSecretValueOutputReference | IntegrationConnectorsConnectionEventingConfigAdditionalVariableSecretValue): any;
export declare class IntegrationConnectorsConnectionEventingConfigAdditionalVariableSecretValueOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionEventingConfigAdditionalVariableSecretValue | undefined;
    set internalValue(value: IntegrationConnectorsConnectionEventingConfigAdditionalVariableSecretValue | undefined);
    private _secretVersion?;
    get secretVersion(): string;
    set secretVersion(value: string);
    get secretVersionInput(): string | undefined;
}
export interface IntegrationConnectorsConnectionEventingConfigAdditionalVariable {
    /**
    * Boolean Value of configVariable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#boolean_value IntegrationConnectorsConnection#boolean_value}
    */
    readonly booleanValue?: boolean | cdktf.IResolvable;
    /**
    * Integer Value of configVariable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#integer_value IntegrationConnectorsConnection#integer_value}
    */
    readonly integerValue?: number;
    /**
    * Key for the configVariable
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#key IntegrationConnectorsConnection#key}
    */
    readonly key: string;
    /**
    * String Value of configVariabley.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#string_value IntegrationConnectorsConnection#string_value}
    */
    readonly stringValue?: string;
    /**
    * encryption_key_value block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#encryption_key_value IntegrationConnectorsConnection#encryption_key_value}
    */
    readonly encryptionKeyValue?: IntegrationConnectorsConnectionEventingConfigAdditionalVariableEncryptionKeyValue;
    /**
    * secret_value block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#secret_value IntegrationConnectorsConnection#secret_value}
    */
    readonly secretValue?: IntegrationConnectorsConnectionEventingConfigAdditionalVariableSecretValue;
}
export declare function integrationConnectorsConnectionEventingConfigAdditionalVariableToTerraform(struct?: IntegrationConnectorsConnectionEventingConfigAdditionalVariable | cdktf.IResolvable): any;
export declare function integrationConnectorsConnectionEventingConfigAdditionalVariableToHclTerraform(struct?: IntegrationConnectorsConnectionEventingConfigAdditionalVariable | cdktf.IResolvable): any;
export declare class IntegrationConnectorsConnectionEventingConfigAdditionalVariableOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): IntegrationConnectorsConnectionEventingConfigAdditionalVariable | cdktf.IResolvable | undefined;
    set internalValue(value: IntegrationConnectorsConnectionEventingConfigAdditionalVariable | cdktf.IResolvable | undefined);
    private _booleanValue?;
    get booleanValue(): boolean | cdktf.IResolvable;
    set booleanValue(value: boolean | cdktf.IResolvable);
    resetBooleanValue(): void;
    get booleanValueInput(): boolean | cdktf.IResolvable | undefined;
    private _integerValue?;
    get integerValue(): number;
    set integerValue(value: number);
    resetIntegerValue(): void;
    get integerValueInput(): number | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _stringValue?;
    get stringValue(): string;
    set stringValue(value: string);
    resetStringValue(): void;
    get stringValueInput(): string | undefined;
    private _encryptionKeyValue;
    get encryptionKeyValue(): IntegrationConnectorsConnectionEventingConfigAdditionalVariableEncryptionKeyValueOutputReference;
    putEncryptionKeyValue(value: IntegrationConnectorsConnectionEventingConfigAdditionalVariableEncryptionKeyValue): void;
    resetEncryptionKeyValue(): void;
    get encryptionKeyValueInput(): IntegrationConnectorsConnectionEventingConfigAdditionalVariableEncryptionKeyValue | undefined;
    private _secretValue;
    get secretValue(): IntegrationConnectorsConnectionEventingConfigAdditionalVariableSecretValueOutputReference;
    putSecretValue(value: IntegrationConnectorsConnectionEventingConfigAdditionalVariableSecretValue): void;
    resetSecretValue(): void;
    get secretValueInput(): IntegrationConnectorsConnectionEventingConfigAdditionalVariableSecretValue | undefined;
}
export declare class IntegrationConnectorsConnectionEventingConfigAdditionalVariableList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: IntegrationConnectorsConnectionEventingConfigAdditionalVariable[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): IntegrationConnectorsConnectionEventingConfigAdditionalVariableOutputReference;
}
export interface IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableEncryptionKeyValue {
    /**
    * The [KMS key name] with which the content of the Operation is encrypted. The expected
    * format: projects/* /locations/* /keyRings/* /cryptoKeys/*.
    * Will be empty string if google managed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#kms_key_name IntegrationConnectorsConnection#kms_key_name}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly kmsKeyName?: string;
    /**
    * Type of Encription Key Possible values: ["GOOGLE_MANAGED", "CUSTOMER_MANAGED"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#type IntegrationConnectorsConnection#type}
    */
    readonly type?: string;
}
export declare function integrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableEncryptionKeyValueToTerraform(struct?: IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableEncryptionKeyValueOutputReference | IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableEncryptionKeyValue): any;
export declare function integrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableEncryptionKeyValueToHclTerraform(struct?: IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableEncryptionKeyValueOutputReference | IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableEncryptionKeyValue): any;
export declare class IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableEncryptionKeyValueOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableEncryptionKeyValue | undefined;
    set internalValue(value: IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableEncryptionKeyValue | undefined);
    private _kmsKeyName?;
    get kmsKeyName(): string;
    set kmsKeyName(value: string);
    resetKmsKeyName(): void;
    get kmsKeyNameInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
}
export interface IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableSecretValue {
    /**
    * Secret version of Secret Value for Config variable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#secret_version IntegrationConnectorsConnection#secret_version}
    */
    readonly secretVersion: string;
}
export declare function integrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableSecretValueToTerraform(struct?: IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableSecretValueOutputReference | IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableSecretValue): any;
export declare function integrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableSecretValueToHclTerraform(struct?: IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableSecretValueOutputReference | IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableSecretValue): any;
export declare class IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableSecretValueOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableSecretValue | undefined;
    set internalValue(value: IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableSecretValue | undefined);
    private _secretVersion?;
    get secretVersion(): string;
    set secretVersion(value: string);
    get secretVersionInput(): string | undefined;
}
export interface IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariable {
    /**
    * Boolean Value of configVariable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#boolean_value IntegrationConnectorsConnection#boolean_value}
    */
    readonly booleanValue?: boolean | cdktf.IResolvable;
    /**
    * Integer Value of configVariable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#integer_value IntegrationConnectorsConnection#integer_value}
    */
    readonly integerValue?: number;
    /**
    * Key for the configVariable
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#key IntegrationConnectorsConnection#key}
    */
    readonly key: string;
    /**
    * String Value of configVariabley.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#string_value IntegrationConnectorsConnection#string_value}
    */
    readonly stringValue?: string;
    /**
    * encryption_key_value block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#encryption_key_value IntegrationConnectorsConnection#encryption_key_value}
    */
    readonly encryptionKeyValue?: IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableEncryptionKeyValue;
    /**
    * secret_value block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#secret_value IntegrationConnectorsConnection#secret_value}
    */
    readonly secretValue?: IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableSecretValue;
}
export declare function integrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableToTerraform(struct?: IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariable | cdktf.IResolvable): any;
export declare function integrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableToHclTerraform(struct?: IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariable | cdktf.IResolvable): any;
export declare class IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariable | cdktf.IResolvable | undefined;
    set internalValue(value: IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariable | cdktf.IResolvable | undefined);
    private _booleanValue?;
    get booleanValue(): boolean | cdktf.IResolvable;
    set booleanValue(value: boolean | cdktf.IResolvable);
    resetBooleanValue(): void;
    get booleanValueInput(): boolean | cdktf.IResolvable | undefined;
    private _integerValue?;
    get integerValue(): number;
    set integerValue(value: number);
    resetIntegerValue(): void;
    get integerValueInput(): number | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _stringValue?;
    get stringValue(): string;
    set stringValue(value: string);
    resetStringValue(): void;
    get stringValueInput(): string | undefined;
    private _encryptionKeyValue;
    get encryptionKeyValue(): IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableEncryptionKeyValueOutputReference;
    putEncryptionKeyValue(value: IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableEncryptionKeyValue): void;
    resetEncryptionKeyValue(): void;
    get encryptionKeyValueInput(): IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableEncryptionKeyValue | undefined;
    private _secretValue;
    get secretValue(): IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableSecretValueOutputReference;
    putSecretValue(value: IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableSecretValue): void;
    resetSecretValue(): void;
    get secretValueInput(): IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableSecretValue | undefined;
}
export declare class IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariable[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableOutputReference;
}
export interface IntegrationConnectorsConnectionEventingConfigAuthConfigUserPasswordPassword {
    /**
    * The resource name of the secret version in the format,
    * format as: projects/* /secrets/* /versions/*.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#secret_version IntegrationConnectorsConnection#secret_version}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly secretVersion: string;
}
export declare function integrationConnectorsConnectionEventingConfigAuthConfigUserPasswordPasswordToTerraform(struct?: IntegrationConnectorsConnectionEventingConfigAuthConfigUserPasswordPasswordOutputReference | IntegrationConnectorsConnectionEventingConfigAuthConfigUserPasswordPassword): any;
export declare function integrationConnectorsConnectionEventingConfigAuthConfigUserPasswordPasswordToHclTerraform(struct?: IntegrationConnectorsConnectionEventingConfigAuthConfigUserPasswordPasswordOutputReference | IntegrationConnectorsConnectionEventingConfigAuthConfigUserPasswordPassword): any;
export declare class IntegrationConnectorsConnectionEventingConfigAuthConfigUserPasswordPasswordOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionEventingConfigAuthConfigUserPasswordPassword | undefined;
    set internalValue(value: IntegrationConnectorsConnectionEventingConfigAuthConfigUserPasswordPassword | undefined);
    private _secretVersion?;
    get secretVersion(): string;
    set secretVersion(value: string);
    get secretVersionInput(): string | undefined;
}
export interface IntegrationConnectorsConnectionEventingConfigAuthConfigUserPassword {
    /**
    * Username for Authentication.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#username IntegrationConnectorsConnection#username}
    */
    readonly username?: string;
    /**
    * password block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#password IntegrationConnectorsConnection#password}
    */
    readonly password?: IntegrationConnectorsConnectionEventingConfigAuthConfigUserPasswordPassword;
}
export declare function integrationConnectorsConnectionEventingConfigAuthConfigUserPasswordToTerraform(struct?: IntegrationConnectorsConnectionEventingConfigAuthConfigUserPasswordOutputReference | IntegrationConnectorsConnectionEventingConfigAuthConfigUserPassword): any;
export declare function integrationConnectorsConnectionEventingConfigAuthConfigUserPasswordToHclTerraform(struct?: IntegrationConnectorsConnectionEventingConfigAuthConfigUserPasswordOutputReference | IntegrationConnectorsConnectionEventingConfigAuthConfigUserPassword): any;
export declare class IntegrationConnectorsConnectionEventingConfigAuthConfigUserPasswordOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionEventingConfigAuthConfigUserPassword | undefined;
    set internalValue(value: IntegrationConnectorsConnectionEventingConfigAuthConfigUserPassword | undefined);
    private _username?;
    get username(): string;
    set username(value: string);
    resetUsername(): void;
    get usernameInput(): string | undefined;
    private _password;
    get password(): IntegrationConnectorsConnectionEventingConfigAuthConfigUserPasswordPasswordOutputReference;
    putPassword(value: IntegrationConnectorsConnectionEventingConfigAuthConfigUserPasswordPassword): void;
    resetPassword(): void;
    get passwordInput(): IntegrationConnectorsConnectionEventingConfigAuthConfigUserPasswordPassword | undefined;
}
export interface IntegrationConnectorsConnectionEventingConfigAuthConfig {
    /**
    * The type of authentication configured.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#auth_key IntegrationConnectorsConnection#auth_key}
    */
    readonly authKey?: string;
    /**
    * authType of the Connection Possible values: ["USER_PASSWORD"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#auth_type IntegrationConnectorsConnection#auth_type}
    */
    readonly authType: string;
    /**
    * additional_variable block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#additional_variable IntegrationConnectorsConnection#additional_variable}
    */
    readonly additionalVariable?: IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariable[] | cdktf.IResolvable;
    /**
    * user_password block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#user_password IntegrationConnectorsConnection#user_password}
    */
    readonly userPassword: IntegrationConnectorsConnectionEventingConfigAuthConfigUserPassword;
}
export declare function integrationConnectorsConnectionEventingConfigAuthConfigToTerraform(struct?: IntegrationConnectorsConnectionEventingConfigAuthConfigOutputReference | IntegrationConnectorsConnectionEventingConfigAuthConfig): any;
export declare function integrationConnectorsConnectionEventingConfigAuthConfigToHclTerraform(struct?: IntegrationConnectorsConnectionEventingConfigAuthConfigOutputReference | IntegrationConnectorsConnectionEventingConfigAuthConfig): any;
export declare class IntegrationConnectorsConnectionEventingConfigAuthConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionEventingConfigAuthConfig | undefined;
    set internalValue(value: IntegrationConnectorsConnectionEventingConfigAuthConfig | undefined);
    private _authKey?;
    get authKey(): string;
    set authKey(value: string);
    resetAuthKey(): void;
    get authKeyInput(): string | undefined;
    private _authType?;
    get authType(): string;
    set authType(value: string);
    get authTypeInput(): string | undefined;
    private _additionalVariable;
    get additionalVariable(): IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariableList;
    putAdditionalVariable(value: IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariable[] | cdktf.IResolvable): void;
    resetAdditionalVariable(): void;
    get additionalVariableInput(): cdktf.IResolvable | IntegrationConnectorsConnectionEventingConfigAuthConfigAdditionalVariable[] | undefined;
    private _userPassword;
    get userPassword(): IntegrationConnectorsConnectionEventingConfigAuthConfigUserPasswordOutputReference;
    putUserPassword(value: IntegrationConnectorsConnectionEventingConfigAuthConfigUserPassword): void;
    get userPasswordInput(): IntegrationConnectorsConnectionEventingConfigAuthConfigUserPassword | undefined;
}
export interface IntegrationConnectorsConnectionEventingConfigRegistrationDestinationConfigDestination {
    /**
    * Host
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#host IntegrationConnectorsConnection#host}
    */
    readonly host?: string;
    /**
    * port number
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#port IntegrationConnectorsConnection#port}
    */
    readonly port?: number;
    /**
    * Service Attachment
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#service_attachment IntegrationConnectorsConnection#service_attachment}
    */
    readonly serviceAttachment?: string;
}
export declare function integrationConnectorsConnectionEventingConfigRegistrationDestinationConfigDestinationToTerraform(struct?: IntegrationConnectorsConnectionEventingConfigRegistrationDestinationConfigDestination | cdktf.IResolvable): any;
export declare function integrationConnectorsConnectionEventingConfigRegistrationDestinationConfigDestinationToHclTerraform(struct?: IntegrationConnectorsConnectionEventingConfigRegistrationDestinationConfigDestination | cdktf.IResolvable): any;
export declare class IntegrationConnectorsConnectionEventingConfigRegistrationDestinationConfigDestinationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): IntegrationConnectorsConnectionEventingConfigRegistrationDestinationConfigDestination | cdktf.IResolvable | undefined;
    set internalValue(value: IntegrationConnectorsConnectionEventingConfigRegistrationDestinationConfigDestination | cdktf.IResolvable | undefined);
    private _host?;
    get host(): string;
    set host(value: string);
    resetHost(): void;
    get hostInput(): string | undefined;
    private _port?;
    get port(): number;
    set port(value: number);
    resetPort(): void;
    get portInput(): number | undefined;
    private _serviceAttachment?;
    get serviceAttachment(): string;
    set serviceAttachment(value: string);
    resetServiceAttachment(): void;
    get serviceAttachmentInput(): string | undefined;
}
export declare class IntegrationConnectorsConnectionEventingConfigRegistrationDestinationConfigDestinationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: IntegrationConnectorsConnectionEventingConfigRegistrationDestinationConfigDestination[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): IntegrationConnectorsConnectionEventingConfigRegistrationDestinationConfigDestinationOutputReference;
}
export interface IntegrationConnectorsConnectionEventingConfigRegistrationDestinationConfig {
    /**
    * Key for the connection
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#key IntegrationConnectorsConnection#key}
    */
    readonly key?: string;
    /**
    * destination block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#destination IntegrationConnectorsConnection#destination}
    */
    readonly destination?: IntegrationConnectorsConnectionEventingConfigRegistrationDestinationConfigDestination[] | cdktf.IResolvable;
}
export declare function integrationConnectorsConnectionEventingConfigRegistrationDestinationConfigToTerraform(struct?: IntegrationConnectorsConnectionEventingConfigRegistrationDestinationConfigOutputReference | IntegrationConnectorsConnectionEventingConfigRegistrationDestinationConfig): any;
export declare function integrationConnectorsConnectionEventingConfigRegistrationDestinationConfigToHclTerraform(struct?: IntegrationConnectorsConnectionEventingConfigRegistrationDestinationConfigOutputReference | IntegrationConnectorsConnectionEventingConfigRegistrationDestinationConfig): any;
export declare class IntegrationConnectorsConnectionEventingConfigRegistrationDestinationConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionEventingConfigRegistrationDestinationConfig | undefined;
    set internalValue(value: IntegrationConnectorsConnectionEventingConfigRegistrationDestinationConfig | undefined);
    private _key?;
    get key(): string;
    set key(value: string);
    resetKey(): void;
    get keyInput(): string | undefined;
    private _destination;
    get destination(): IntegrationConnectorsConnectionEventingConfigRegistrationDestinationConfigDestinationList;
    putDestination(value: IntegrationConnectorsConnectionEventingConfigRegistrationDestinationConfigDestination[] | cdktf.IResolvable): void;
    resetDestination(): void;
    get destinationInput(): cdktf.IResolvable | IntegrationConnectorsConnectionEventingConfigRegistrationDestinationConfigDestination[] | undefined;
}
export interface IntegrationConnectorsConnectionEventingConfig {
    /**
    * Enrichment Enabled.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#enrichment_enabled IntegrationConnectorsConnection#enrichment_enabled}
    */
    readonly enrichmentEnabled?: boolean | cdktf.IResolvable;
    /**
    * additional_variable block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#additional_variable IntegrationConnectorsConnection#additional_variable}
    */
    readonly additionalVariable?: IntegrationConnectorsConnectionEventingConfigAdditionalVariable[] | cdktf.IResolvable;
    /**
    * auth_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#auth_config IntegrationConnectorsConnection#auth_config}
    */
    readonly authConfig?: IntegrationConnectorsConnectionEventingConfigAuthConfig;
    /**
    * registration_destination_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#registration_destination_config IntegrationConnectorsConnection#registration_destination_config}
    */
    readonly registrationDestinationConfig: IntegrationConnectorsConnectionEventingConfigRegistrationDestinationConfig;
}
export declare function integrationConnectorsConnectionEventingConfigToTerraform(struct?: IntegrationConnectorsConnectionEventingConfigOutputReference | IntegrationConnectorsConnectionEventingConfig): any;
export declare function integrationConnectorsConnectionEventingConfigToHclTerraform(struct?: IntegrationConnectorsConnectionEventingConfigOutputReference | IntegrationConnectorsConnectionEventingConfig): any;
export declare class IntegrationConnectorsConnectionEventingConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionEventingConfig | undefined;
    set internalValue(value: IntegrationConnectorsConnectionEventingConfig | undefined);
    private _enrichmentEnabled?;
    get enrichmentEnabled(): boolean | cdktf.IResolvable;
    set enrichmentEnabled(value: boolean | cdktf.IResolvable);
    resetEnrichmentEnabled(): void;
    get enrichmentEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _additionalVariable;
    get additionalVariable(): IntegrationConnectorsConnectionEventingConfigAdditionalVariableList;
    putAdditionalVariable(value: IntegrationConnectorsConnectionEventingConfigAdditionalVariable[] | cdktf.IResolvable): void;
    resetAdditionalVariable(): void;
    get additionalVariableInput(): cdktf.IResolvable | IntegrationConnectorsConnectionEventingConfigAdditionalVariable[] | undefined;
    private _authConfig;
    get authConfig(): IntegrationConnectorsConnectionEventingConfigAuthConfigOutputReference;
    putAuthConfig(value: IntegrationConnectorsConnectionEventingConfigAuthConfig): void;
    resetAuthConfig(): void;
    get authConfigInput(): IntegrationConnectorsConnectionEventingConfigAuthConfig | undefined;
    private _registrationDestinationConfig;
    get registrationDestinationConfig(): IntegrationConnectorsConnectionEventingConfigRegistrationDestinationConfigOutputReference;
    putRegistrationDestinationConfig(value: IntegrationConnectorsConnectionEventingConfigRegistrationDestinationConfig): void;
    get registrationDestinationConfigInput(): IntegrationConnectorsConnectionEventingConfigRegistrationDestinationConfig | undefined;
}
export interface IntegrationConnectorsConnectionLockConfig {
    /**
    * Indicates whether or not the connection is locked.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#locked IntegrationConnectorsConnection#locked}
    */
    readonly locked: boolean | cdktf.IResolvable;
    /**
    * Describes why a connection is locked.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#reason IntegrationConnectorsConnection#reason}
    */
    readonly reason?: string;
}
export declare function integrationConnectorsConnectionLockConfigToTerraform(struct?: IntegrationConnectorsConnectionLockConfigOutputReference | IntegrationConnectorsConnectionLockConfig): any;
export declare function integrationConnectorsConnectionLockConfigToHclTerraform(struct?: IntegrationConnectorsConnectionLockConfigOutputReference | IntegrationConnectorsConnectionLockConfig): any;
export declare class IntegrationConnectorsConnectionLockConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionLockConfig | undefined;
    set internalValue(value: IntegrationConnectorsConnectionLockConfig | undefined);
    private _locked?;
    get locked(): boolean | cdktf.IResolvable;
    set locked(value: boolean | cdktf.IResolvable);
    get lockedInput(): boolean | cdktf.IResolvable | undefined;
    private _reason?;
    get reason(): string;
    set reason(value: string);
    resetReason(): void;
    get reasonInput(): string | undefined;
}
export interface IntegrationConnectorsConnectionLogConfig {
    /**
    * Enabled represents whether logging is enabled or not for a connection.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#enabled IntegrationConnectorsConnection#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
}
export declare function integrationConnectorsConnectionLogConfigToTerraform(struct?: IntegrationConnectorsConnectionLogConfigOutputReference | IntegrationConnectorsConnectionLogConfig): any;
export declare function integrationConnectorsConnectionLogConfigToHclTerraform(struct?: IntegrationConnectorsConnectionLogConfigOutputReference | IntegrationConnectorsConnectionLogConfig): any;
export declare class IntegrationConnectorsConnectionLogConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionLogConfig | undefined;
    set internalValue(value: IntegrationConnectorsConnectionLogConfig | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface IntegrationConnectorsConnectionNodeConfig {
    /**
    * Minimum number of nodes in the runtime nodes.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#max_node_count IntegrationConnectorsConnection#max_node_count}
    */
    readonly maxNodeCount?: number;
    /**
    * Minimum number of nodes in the runtime nodes.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#min_node_count IntegrationConnectorsConnection#min_node_count}
    */
    readonly minNodeCount?: number;
}
export declare function integrationConnectorsConnectionNodeConfigToTerraform(struct?: IntegrationConnectorsConnectionNodeConfigOutputReference | IntegrationConnectorsConnectionNodeConfig): any;
export declare function integrationConnectorsConnectionNodeConfigToHclTerraform(struct?: IntegrationConnectorsConnectionNodeConfigOutputReference | IntegrationConnectorsConnectionNodeConfig): any;
export declare class IntegrationConnectorsConnectionNodeConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionNodeConfig | undefined;
    set internalValue(value: IntegrationConnectorsConnectionNodeConfig | undefined);
    private _maxNodeCount?;
    get maxNodeCount(): number;
    set maxNodeCount(value: number);
    resetMaxNodeCount(): void;
    get maxNodeCountInput(): number | undefined;
    private _minNodeCount?;
    get minNodeCount(): number;
    set minNodeCount(value: number);
    resetMinNodeCount(): void;
    get minNodeCountInput(): number | undefined;
}
export interface IntegrationConnectorsConnectionSslConfigAdditionalVariableEncryptionKeyValue {
    /**
    * The [KMS key name] with which the content of the Operation is encrypted. The expected
    * format: projects/* /locations/* /keyRings/* /cryptoKeys/*.
    * Will be empty string if google managed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#kms_key_name IntegrationConnectorsConnection#kms_key_name}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly kmsKeyName?: string;
    /**
    * Type of Encription Key Possible values: ["GOOGLE_MANAGED", "CUSTOMER_MANAGED"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#type IntegrationConnectorsConnection#type}
    */
    readonly type?: string;
}
export declare function integrationConnectorsConnectionSslConfigAdditionalVariableEncryptionKeyValueToTerraform(struct?: IntegrationConnectorsConnectionSslConfigAdditionalVariableEncryptionKeyValueOutputReference | IntegrationConnectorsConnectionSslConfigAdditionalVariableEncryptionKeyValue): any;
export declare function integrationConnectorsConnectionSslConfigAdditionalVariableEncryptionKeyValueToHclTerraform(struct?: IntegrationConnectorsConnectionSslConfigAdditionalVariableEncryptionKeyValueOutputReference | IntegrationConnectorsConnectionSslConfigAdditionalVariableEncryptionKeyValue): any;
export declare class IntegrationConnectorsConnectionSslConfigAdditionalVariableEncryptionKeyValueOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionSslConfigAdditionalVariableEncryptionKeyValue | undefined;
    set internalValue(value: IntegrationConnectorsConnectionSslConfigAdditionalVariableEncryptionKeyValue | undefined);
    private _kmsKeyName?;
    get kmsKeyName(): string;
    set kmsKeyName(value: string);
    resetKmsKeyName(): void;
    get kmsKeyNameInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
}
export interface IntegrationConnectorsConnectionSslConfigAdditionalVariableSecretValue {
    /**
    * Secret version of Secret Value for Config variable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#secret_version IntegrationConnectorsConnection#secret_version}
    */
    readonly secretVersion: string;
}
export declare function integrationConnectorsConnectionSslConfigAdditionalVariableSecretValueToTerraform(struct?: IntegrationConnectorsConnectionSslConfigAdditionalVariableSecretValueOutputReference | IntegrationConnectorsConnectionSslConfigAdditionalVariableSecretValue): any;
export declare function integrationConnectorsConnectionSslConfigAdditionalVariableSecretValueToHclTerraform(struct?: IntegrationConnectorsConnectionSslConfigAdditionalVariableSecretValueOutputReference | IntegrationConnectorsConnectionSslConfigAdditionalVariableSecretValue): any;
export declare class IntegrationConnectorsConnectionSslConfigAdditionalVariableSecretValueOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionSslConfigAdditionalVariableSecretValue | undefined;
    set internalValue(value: IntegrationConnectorsConnectionSslConfigAdditionalVariableSecretValue | undefined);
    private _secretVersion?;
    get secretVersion(): string;
    set secretVersion(value: string);
    get secretVersionInput(): string | undefined;
}
export interface IntegrationConnectorsConnectionSslConfigAdditionalVariable {
    /**
    * Boolean Value of configVariable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#boolean_value IntegrationConnectorsConnection#boolean_value}
    */
    readonly booleanValue?: boolean | cdktf.IResolvable;
    /**
    * Integer Value of configVariable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#integer_value IntegrationConnectorsConnection#integer_value}
    */
    readonly integerValue?: number;
    /**
    * Key for the configVariable
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#key IntegrationConnectorsConnection#key}
    */
    readonly key: string;
    /**
    * String Value of configVariabley.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#string_value IntegrationConnectorsConnection#string_value}
    */
    readonly stringValue?: string;
    /**
    * encryption_key_value block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#encryption_key_value IntegrationConnectorsConnection#encryption_key_value}
    */
    readonly encryptionKeyValue?: IntegrationConnectorsConnectionSslConfigAdditionalVariableEncryptionKeyValue;
    /**
    * secret_value block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#secret_value IntegrationConnectorsConnection#secret_value}
    */
    readonly secretValue?: IntegrationConnectorsConnectionSslConfigAdditionalVariableSecretValue;
}
export declare function integrationConnectorsConnectionSslConfigAdditionalVariableToTerraform(struct?: IntegrationConnectorsConnectionSslConfigAdditionalVariable | cdktf.IResolvable): any;
export declare function integrationConnectorsConnectionSslConfigAdditionalVariableToHclTerraform(struct?: IntegrationConnectorsConnectionSslConfigAdditionalVariable | cdktf.IResolvable): any;
export declare class IntegrationConnectorsConnectionSslConfigAdditionalVariableOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): IntegrationConnectorsConnectionSslConfigAdditionalVariable | cdktf.IResolvable | undefined;
    set internalValue(value: IntegrationConnectorsConnectionSslConfigAdditionalVariable | cdktf.IResolvable | undefined);
    private _booleanValue?;
    get booleanValue(): boolean | cdktf.IResolvable;
    set booleanValue(value: boolean | cdktf.IResolvable);
    resetBooleanValue(): void;
    get booleanValueInput(): boolean | cdktf.IResolvable | undefined;
    private _integerValue?;
    get integerValue(): number;
    set integerValue(value: number);
    resetIntegerValue(): void;
    get integerValueInput(): number | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _stringValue?;
    get stringValue(): string;
    set stringValue(value: string);
    resetStringValue(): void;
    get stringValueInput(): string | undefined;
    private _encryptionKeyValue;
    get encryptionKeyValue(): IntegrationConnectorsConnectionSslConfigAdditionalVariableEncryptionKeyValueOutputReference;
    putEncryptionKeyValue(value: IntegrationConnectorsConnectionSslConfigAdditionalVariableEncryptionKeyValue): void;
    resetEncryptionKeyValue(): void;
    get encryptionKeyValueInput(): IntegrationConnectorsConnectionSslConfigAdditionalVariableEncryptionKeyValue | undefined;
    private _secretValue;
    get secretValue(): IntegrationConnectorsConnectionSslConfigAdditionalVariableSecretValueOutputReference;
    putSecretValue(value: IntegrationConnectorsConnectionSslConfigAdditionalVariableSecretValue): void;
    resetSecretValue(): void;
    get secretValueInput(): IntegrationConnectorsConnectionSslConfigAdditionalVariableSecretValue | undefined;
}
export declare class IntegrationConnectorsConnectionSslConfigAdditionalVariableList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: IntegrationConnectorsConnectionSslConfigAdditionalVariable[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): IntegrationConnectorsConnectionSslConfigAdditionalVariableOutputReference;
}
export interface IntegrationConnectorsConnectionSslConfigClientCertificate {
    /**
    * Secret version of Secret Value for Config variable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#secret_version IntegrationConnectorsConnection#secret_version}
    */
    readonly secretVersion: string;
}
export declare function integrationConnectorsConnectionSslConfigClientCertificateToTerraform(struct?: IntegrationConnectorsConnectionSslConfigClientCertificateOutputReference | IntegrationConnectorsConnectionSslConfigClientCertificate): any;
export declare function integrationConnectorsConnectionSslConfigClientCertificateToHclTerraform(struct?: IntegrationConnectorsConnectionSslConfigClientCertificateOutputReference | IntegrationConnectorsConnectionSslConfigClientCertificate): any;
export declare class IntegrationConnectorsConnectionSslConfigClientCertificateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionSslConfigClientCertificate | undefined;
    set internalValue(value: IntegrationConnectorsConnectionSslConfigClientCertificate | undefined);
    private _secretVersion?;
    get secretVersion(): string;
    set secretVersion(value: string);
    get secretVersionInput(): string | undefined;
}
export interface IntegrationConnectorsConnectionSslConfigClientPrivateKey {
    /**
    * Secret version of Secret Value for Config variable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#secret_version IntegrationConnectorsConnection#secret_version}
    */
    readonly secretVersion: string;
}
export declare function integrationConnectorsConnectionSslConfigClientPrivateKeyToTerraform(struct?: IntegrationConnectorsConnectionSslConfigClientPrivateKeyOutputReference | IntegrationConnectorsConnectionSslConfigClientPrivateKey): any;
export declare function integrationConnectorsConnectionSslConfigClientPrivateKeyToHclTerraform(struct?: IntegrationConnectorsConnectionSslConfigClientPrivateKeyOutputReference | IntegrationConnectorsConnectionSslConfigClientPrivateKey): any;
export declare class IntegrationConnectorsConnectionSslConfigClientPrivateKeyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionSslConfigClientPrivateKey | undefined;
    set internalValue(value: IntegrationConnectorsConnectionSslConfigClientPrivateKey | undefined);
    private _secretVersion?;
    get secretVersion(): string;
    set secretVersion(value: string);
    get secretVersionInput(): string | undefined;
}
export interface IntegrationConnectorsConnectionSslConfigClientPrivateKeyPass {
    /**
    * Secret version of Secret Value for Config variable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#secret_version IntegrationConnectorsConnection#secret_version}
    */
    readonly secretVersion: string;
}
export declare function integrationConnectorsConnectionSslConfigClientPrivateKeyPassToTerraform(struct?: IntegrationConnectorsConnectionSslConfigClientPrivateKeyPassOutputReference | IntegrationConnectorsConnectionSslConfigClientPrivateKeyPass): any;
export declare function integrationConnectorsConnectionSslConfigClientPrivateKeyPassToHclTerraform(struct?: IntegrationConnectorsConnectionSslConfigClientPrivateKeyPassOutputReference | IntegrationConnectorsConnectionSslConfigClientPrivateKeyPass): any;
export declare class IntegrationConnectorsConnectionSslConfigClientPrivateKeyPassOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionSslConfigClientPrivateKeyPass | undefined;
    set internalValue(value: IntegrationConnectorsConnectionSslConfigClientPrivateKeyPass | undefined);
    private _secretVersion?;
    get secretVersion(): string;
    set secretVersion(value: string);
    get secretVersionInput(): string | undefined;
}
export interface IntegrationConnectorsConnectionSslConfigPrivateServerCertificate {
    /**
    * Secret version of Secret Value for Config variable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#secret_version IntegrationConnectorsConnection#secret_version}
    */
    readonly secretVersion: string;
}
export declare function integrationConnectorsConnectionSslConfigPrivateServerCertificateToTerraform(struct?: IntegrationConnectorsConnectionSslConfigPrivateServerCertificateOutputReference | IntegrationConnectorsConnectionSslConfigPrivateServerCertificate): any;
export declare function integrationConnectorsConnectionSslConfigPrivateServerCertificateToHclTerraform(struct?: IntegrationConnectorsConnectionSslConfigPrivateServerCertificateOutputReference | IntegrationConnectorsConnectionSslConfigPrivateServerCertificate): any;
export declare class IntegrationConnectorsConnectionSslConfigPrivateServerCertificateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionSslConfigPrivateServerCertificate | undefined;
    set internalValue(value: IntegrationConnectorsConnectionSslConfigPrivateServerCertificate | undefined);
    private _secretVersion?;
    get secretVersion(): string;
    set secretVersion(value: string);
    get secretVersionInput(): string | undefined;
}
export interface IntegrationConnectorsConnectionSslConfig {
    /**
    * Type of Client Cert (PEM/JKS/.. etc.) Possible values: ["PEM"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#client_cert_type IntegrationConnectorsConnection#client_cert_type}
    */
    readonly clientCertType?: string;
    /**
    * Type of Server Cert (PEM/JKS/.. etc.) Possible values: ["PEM"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#server_cert_type IntegrationConnectorsConnection#server_cert_type}
    */
    readonly serverCertType?: string;
    /**
    * Enum for Trust Model Possible values: ["PUBLIC", "PRIVATE", "INSECURE"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#trust_model IntegrationConnectorsConnection#trust_model}
    */
    readonly trustModel?: string;
    /**
    * Enum for controlling the SSL Type (TLS/MTLS) Possible values: ["TLS", "MTLS"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#type IntegrationConnectorsConnection#type}
    */
    readonly type: string;
    /**
    * Bool for enabling SSL
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#use_ssl IntegrationConnectorsConnection#use_ssl}
    */
    readonly useSsl?: boolean | cdktf.IResolvable;
    /**
    * additional_variable block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#additional_variable IntegrationConnectorsConnection#additional_variable}
    */
    readonly additionalVariable?: IntegrationConnectorsConnectionSslConfigAdditionalVariable[] | cdktf.IResolvable;
    /**
    * client_certificate block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#client_certificate IntegrationConnectorsConnection#client_certificate}
    */
    readonly clientCertificate?: IntegrationConnectorsConnectionSslConfigClientCertificate;
    /**
    * client_private_key block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#client_private_key IntegrationConnectorsConnection#client_private_key}
    */
    readonly clientPrivateKey?: IntegrationConnectorsConnectionSslConfigClientPrivateKey;
    /**
    * client_private_key_pass block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#client_private_key_pass IntegrationConnectorsConnection#client_private_key_pass}
    */
    readonly clientPrivateKeyPass?: IntegrationConnectorsConnectionSslConfigClientPrivateKeyPass;
    /**
    * private_server_certificate block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#private_server_certificate IntegrationConnectorsConnection#private_server_certificate}
    */
    readonly privateServerCertificate?: IntegrationConnectorsConnectionSslConfigPrivateServerCertificate;
}
export declare function integrationConnectorsConnectionSslConfigToTerraform(struct?: IntegrationConnectorsConnectionSslConfigOutputReference | IntegrationConnectorsConnectionSslConfig): any;
export declare function integrationConnectorsConnectionSslConfigToHclTerraform(struct?: IntegrationConnectorsConnectionSslConfigOutputReference | IntegrationConnectorsConnectionSslConfig): any;
export declare class IntegrationConnectorsConnectionSslConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionSslConfig | undefined;
    set internalValue(value: IntegrationConnectorsConnectionSslConfig | undefined);
    private _clientCertType?;
    get clientCertType(): string;
    set clientCertType(value: string);
    resetClientCertType(): void;
    get clientCertTypeInput(): string | undefined;
    private _serverCertType?;
    get serverCertType(): string;
    set serverCertType(value: string);
    resetServerCertType(): void;
    get serverCertTypeInput(): string | undefined;
    private _trustModel?;
    get trustModel(): string;
    set trustModel(value: string);
    resetTrustModel(): void;
    get trustModelInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    private _useSsl?;
    get useSsl(): boolean | cdktf.IResolvable;
    set useSsl(value: boolean | cdktf.IResolvable);
    resetUseSsl(): void;
    get useSslInput(): boolean | cdktf.IResolvable | undefined;
    private _additionalVariable;
    get additionalVariable(): IntegrationConnectorsConnectionSslConfigAdditionalVariableList;
    putAdditionalVariable(value: IntegrationConnectorsConnectionSslConfigAdditionalVariable[] | cdktf.IResolvable): void;
    resetAdditionalVariable(): void;
    get additionalVariableInput(): cdktf.IResolvable | IntegrationConnectorsConnectionSslConfigAdditionalVariable[] | undefined;
    private _clientCertificate;
    get clientCertificate(): IntegrationConnectorsConnectionSslConfigClientCertificateOutputReference;
    putClientCertificate(value: IntegrationConnectorsConnectionSslConfigClientCertificate): void;
    resetClientCertificate(): void;
    get clientCertificateInput(): IntegrationConnectorsConnectionSslConfigClientCertificate | undefined;
    private _clientPrivateKey;
    get clientPrivateKey(): IntegrationConnectorsConnectionSslConfigClientPrivateKeyOutputReference;
    putClientPrivateKey(value: IntegrationConnectorsConnectionSslConfigClientPrivateKey): void;
    resetClientPrivateKey(): void;
    get clientPrivateKeyInput(): IntegrationConnectorsConnectionSslConfigClientPrivateKey | undefined;
    private _clientPrivateKeyPass;
    get clientPrivateKeyPass(): IntegrationConnectorsConnectionSslConfigClientPrivateKeyPassOutputReference;
    putClientPrivateKeyPass(value: IntegrationConnectorsConnectionSslConfigClientPrivateKeyPass): void;
    resetClientPrivateKeyPass(): void;
    get clientPrivateKeyPassInput(): IntegrationConnectorsConnectionSslConfigClientPrivateKeyPass | undefined;
    private _privateServerCertificate;
    get privateServerCertificate(): IntegrationConnectorsConnectionSslConfigPrivateServerCertificateOutputReference;
    putPrivateServerCertificate(value: IntegrationConnectorsConnectionSslConfigPrivateServerCertificate): void;
    resetPrivateServerCertificate(): void;
    get privateServerCertificateInput(): IntegrationConnectorsConnectionSslConfigPrivateServerCertificate | undefined;
}
export interface IntegrationConnectorsConnectionTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#create IntegrationConnectorsConnection#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#delete IntegrationConnectorsConnection#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#update IntegrationConnectorsConnection#update}
    */
    readonly update?: string;
}
export declare function integrationConnectorsConnectionTimeoutsToTerraform(struct?: IntegrationConnectorsConnectionTimeouts | cdktf.IResolvable): any;
export declare function integrationConnectorsConnectionTimeoutsToHclTerraform(struct?: IntegrationConnectorsConnectionTimeouts | cdktf.IResolvable): any;
export declare class IntegrationConnectorsConnectionTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IntegrationConnectorsConnectionTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: IntegrationConnectorsConnectionTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection google_integration_connectors_connection}
*/
export declare class IntegrationConnectorsConnection extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_integration_connectors_connection";
    /**
    * Generates CDKTF code for importing a IntegrationConnectorsConnection resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the IntegrationConnectorsConnection to import
    * @param importFromId The id of the existing IntegrationConnectorsConnection that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the IntegrationConnectorsConnection to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/integration_connectors_connection google_integration_connectors_connection} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options IntegrationConnectorsConnectionConfig
    */
    constructor(scope: Construct, id: string, config: IntegrationConnectorsConnectionConfig);
    get connectionRevision(): string;
    private _connectorVersion?;
    get connectorVersion(): string;
    set connectorVersion(value: string);
    get connectorVersionInput(): string | undefined;
    private _connectorVersionInfraConfig;
    get connectorVersionInfraConfig(): IntegrationConnectorsConnectionConnectorVersionInfraConfigList;
    get connectorVersionLaunchStage(): string;
    get createTime(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _eventingEnablementType?;
    get eventingEnablementType(): string;
    set eventingEnablementType(value: string);
    resetEventingEnablementType(): void;
    get eventingEnablementTypeInput(): string | undefined;
    private _eventingRuntimeData;
    get eventingRuntimeData(): IntegrationConnectorsConnectionEventingRuntimeDataList;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _serviceAccount?;
    get serviceAccount(): string;
    set serviceAccount(value: string);
    resetServiceAccount(): void;
    get serviceAccountInput(): string | undefined;
    get serviceDirectory(): string;
    private _status;
    get status(): IntegrationConnectorsConnectionStatusList;
    get subscriptionType(): string;
    private _suspended?;
    get suspended(): boolean | cdktf.IResolvable;
    set suspended(value: boolean | cdktf.IResolvable);
    resetSuspended(): void;
    get suspendedInput(): boolean | cdktf.IResolvable | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get updateTime(): string;
    private _authConfig;
    get authConfig(): IntegrationConnectorsConnectionAuthConfigOutputReference;
    putAuthConfig(value: IntegrationConnectorsConnectionAuthConfig): void;
    resetAuthConfig(): void;
    get authConfigInput(): IntegrationConnectorsConnectionAuthConfig | undefined;
    private _configVariable;
    get configVariable(): IntegrationConnectorsConnectionConfigVariableList;
    putConfigVariable(value: IntegrationConnectorsConnectionConfigVariable[] | cdktf.IResolvable): void;
    resetConfigVariable(): void;
    get configVariableInput(): cdktf.IResolvable | IntegrationConnectorsConnectionConfigVariable[] | undefined;
    private _destinationConfig;
    get destinationConfig(): IntegrationConnectorsConnectionDestinationConfigList;
    putDestinationConfig(value: IntegrationConnectorsConnectionDestinationConfig[] | cdktf.IResolvable): void;
    resetDestinationConfig(): void;
    get destinationConfigInput(): cdktf.IResolvable | IntegrationConnectorsConnectionDestinationConfig[] | undefined;
    private _eventingConfig;
    get eventingConfig(): IntegrationConnectorsConnectionEventingConfigOutputReference;
    putEventingConfig(value: IntegrationConnectorsConnectionEventingConfig): void;
    resetEventingConfig(): void;
    get eventingConfigInput(): IntegrationConnectorsConnectionEventingConfig | undefined;
    private _lockConfig;
    get lockConfig(): IntegrationConnectorsConnectionLockConfigOutputReference;
    putLockConfig(value: IntegrationConnectorsConnectionLockConfig): void;
    resetLockConfig(): void;
    get lockConfigInput(): IntegrationConnectorsConnectionLockConfig | undefined;
    private _logConfig;
    get logConfig(): IntegrationConnectorsConnectionLogConfigOutputReference;
    putLogConfig(value: IntegrationConnectorsConnectionLogConfig): void;
    resetLogConfig(): void;
    get logConfigInput(): IntegrationConnectorsConnectionLogConfig | undefined;
    private _nodeConfig;
    get nodeConfig(): IntegrationConnectorsConnectionNodeConfigOutputReference;
    putNodeConfig(value: IntegrationConnectorsConnectionNodeConfig): void;
    resetNodeConfig(): void;
    get nodeConfigInput(): IntegrationConnectorsConnectionNodeConfig | undefined;
    private _sslConfig;
    get sslConfig(): IntegrationConnectorsConnectionSslConfigOutputReference;
    putSslConfig(value: IntegrationConnectorsConnectionSslConfig): void;
    resetSslConfig(): void;
    get sslConfigInput(): IntegrationConnectorsConnectionSslConfig | undefined;
    private _timeouts;
    get timeouts(): IntegrationConnectorsConnectionTimeoutsOutputReference;
    putTimeouts(value: IntegrationConnectorsConnectionTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | IntegrationConnectorsConnectionTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
