/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SccOrganizationCustomModuleConfig extends cdktf.TerraformMetaArguments {
    /**
    * The display name of the Security Health Analytics custom module. This
    * display name becomes the finding category for all findings that are
    * returned by this custom module. The display name must be between 1 and
    * 128 characters, start with a lowercase letter, and contain alphanumeric
    * characters or underscores only.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#display_name SccOrganizationCustomModule#display_name}
    */
    readonly displayName: string;
    /**
    * The enablement state of the custom module. Possible values: ["ENABLED", "DISABLED"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#enablement_state SccOrganizationCustomModule#enablement_state}
    */
    readonly enablementState: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#id SccOrganizationCustomModule#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Numerical ID of the parent organization.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#organization SccOrganizationCustomModule#organization}
    */
    readonly organization: string;
    /**
    * custom_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#custom_config SccOrganizationCustomModule#custom_config}
    */
    readonly customConfig: SccOrganizationCustomModuleCustomConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#timeouts SccOrganizationCustomModule#timeouts}
    */
    readonly timeouts?: SccOrganizationCustomModuleTimeouts;
}
export interface SccOrganizationCustomModuleCustomConfigCustomOutputPropertiesValueExpression {
    /**
    * Description of the expression. This is a longer text which describes the
    * expression, e.g. when hovered over it in a UI.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#description SccOrganizationCustomModule#description}
    */
    readonly description?: string;
    /**
    * Textual representation of an expression in Common Expression Language syntax.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#expression SccOrganizationCustomModule#expression}
    */
    readonly expression: string;
    /**
    * String indicating the location of the expression for error reporting, e.g. a
    * file name and a position in the file.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#location SccOrganizationCustomModule#location}
    */
    readonly location?: string;
    /**
    * Title for the expression, i.e. a short string describing its purpose. This can
    * be used e.g. in UIs which allow to enter the expression.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#title SccOrganizationCustomModule#title}
    */
    readonly title?: string;
}
export declare function sccOrganizationCustomModuleCustomConfigCustomOutputPropertiesValueExpressionToTerraform(struct?: SccOrganizationCustomModuleCustomConfigCustomOutputPropertiesValueExpressionOutputReference | SccOrganizationCustomModuleCustomConfigCustomOutputPropertiesValueExpression): any;
export declare function sccOrganizationCustomModuleCustomConfigCustomOutputPropertiesValueExpressionToHclTerraform(struct?: SccOrganizationCustomModuleCustomConfigCustomOutputPropertiesValueExpressionOutputReference | SccOrganizationCustomModuleCustomConfigCustomOutputPropertiesValueExpression): any;
export declare class SccOrganizationCustomModuleCustomConfigCustomOutputPropertiesValueExpressionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SccOrganizationCustomModuleCustomConfigCustomOutputPropertiesValueExpression | undefined;
    set internalValue(value: SccOrganizationCustomModuleCustomConfigCustomOutputPropertiesValueExpression | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _expression?;
    get expression(): string;
    set expression(value: string);
    get expressionInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    private _title?;
    get title(): string;
    set title(value: string);
    resetTitle(): void;
    get titleInput(): string | undefined;
}
export interface SccOrganizationCustomModuleCustomConfigCustomOutputProperties {
    /**
    * Name of the property for the custom output.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#name SccOrganizationCustomModule#name}
    */
    readonly name?: string;
    /**
    * value_expression block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#value_expression SccOrganizationCustomModule#value_expression}
    */
    readonly valueExpression?: SccOrganizationCustomModuleCustomConfigCustomOutputPropertiesValueExpression;
}
export declare function sccOrganizationCustomModuleCustomConfigCustomOutputPropertiesToTerraform(struct?: SccOrganizationCustomModuleCustomConfigCustomOutputProperties | cdktf.IResolvable): any;
export declare function sccOrganizationCustomModuleCustomConfigCustomOutputPropertiesToHclTerraform(struct?: SccOrganizationCustomModuleCustomConfigCustomOutputProperties | cdktf.IResolvable): any;
export declare class SccOrganizationCustomModuleCustomConfigCustomOutputPropertiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): SccOrganizationCustomModuleCustomConfigCustomOutputProperties | cdktf.IResolvable | undefined;
    set internalValue(value: SccOrganizationCustomModuleCustomConfigCustomOutputProperties | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _valueExpression;
    get valueExpression(): SccOrganizationCustomModuleCustomConfigCustomOutputPropertiesValueExpressionOutputReference;
    putValueExpression(value: SccOrganizationCustomModuleCustomConfigCustomOutputPropertiesValueExpression): void;
    resetValueExpression(): void;
    get valueExpressionInput(): SccOrganizationCustomModuleCustomConfigCustomOutputPropertiesValueExpression | undefined;
}
export declare class SccOrganizationCustomModuleCustomConfigCustomOutputPropertiesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: SccOrganizationCustomModuleCustomConfigCustomOutputProperties[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): SccOrganizationCustomModuleCustomConfigCustomOutputPropertiesOutputReference;
}
export interface SccOrganizationCustomModuleCustomConfigCustomOutput {
    /**
    * properties block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#properties SccOrganizationCustomModule#properties}
    */
    readonly properties?: SccOrganizationCustomModuleCustomConfigCustomOutputProperties[] | cdktf.IResolvable;
}
export declare function sccOrganizationCustomModuleCustomConfigCustomOutputToTerraform(struct?: SccOrganizationCustomModuleCustomConfigCustomOutputOutputReference | SccOrganizationCustomModuleCustomConfigCustomOutput): any;
export declare function sccOrganizationCustomModuleCustomConfigCustomOutputToHclTerraform(struct?: SccOrganizationCustomModuleCustomConfigCustomOutputOutputReference | SccOrganizationCustomModuleCustomConfigCustomOutput): any;
export declare class SccOrganizationCustomModuleCustomConfigCustomOutputOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SccOrganizationCustomModuleCustomConfigCustomOutput | undefined;
    set internalValue(value: SccOrganizationCustomModuleCustomConfigCustomOutput | undefined);
    private _properties;
    get properties(): SccOrganizationCustomModuleCustomConfigCustomOutputPropertiesList;
    putProperties(value: SccOrganizationCustomModuleCustomConfigCustomOutputProperties[] | cdktf.IResolvable): void;
    resetProperties(): void;
    get propertiesInput(): cdktf.IResolvable | SccOrganizationCustomModuleCustomConfigCustomOutputProperties[] | undefined;
}
export interface SccOrganizationCustomModuleCustomConfigPredicate {
    /**
    * Description of the expression. This is a longer text which describes the
    * expression, e.g. when hovered over it in a UI.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#description SccOrganizationCustomModule#description}
    */
    readonly description?: string;
    /**
    * Textual representation of an expression in Common Expression Language syntax.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#expression SccOrganizationCustomModule#expression}
    */
    readonly expression: string;
    /**
    * String indicating the location of the expression for error reporting, e.g. a
    * file name and a position in the file.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#location SccOrganizationCustomModule#location}
    */
    readonly location?: string;
    /**
    * Title for the expression, i.e. a short string describing its purpose. This can
    * be used e.g. in UIs which allow to enter the expression.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#title SccOrganizationCustomModule#title}
    */
    readonly title?: string;
}
export declare function sccOrganizationCustomModuleCustomConfigPredicateToTerraform(struct?: SccOrganizationCustomModuleCustomConfigPredicateOutputReference | SccOrganizationCustomModuleCustomConfigPredicate): any;
export declare function sccOrganizationCustomModuleCustomConfigPredicateToHclTerraform(struct?: SccOrganizationCustomModuleCustomConfigPredicateOutputReference | SccOrganizationCustomModuleCustomConfigPredicate): any;
export declare class SccOrganizationCustomModuleCustomConfigPredicateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SccOrganizationCustomModuleCustomConfigPredicate | undefined;
    set internalValue(value: SccOrganizationCustomModuleCustomConfigPredicate | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _expression?;
    get expression(): string;
    set expression(value: string);
    get expressionInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    private _title?;
    get title(): string;
    set title(value: string);
    resetTitle(): void;
    get titleInput(): string | undefined;
}
export interface SccOrganizationCustomModuleCustomConfigResourceSelector {
    /**
    * The resource types to run the detector on.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#resource_types SccOrganizationCustomModule#resource_types}
    */
    readonly resourceTypes: string[];
}
export declare function sccOrganizationCustomModuleCustomConfigResourceSelectorToTerraform(struct?: SccOrganizationCustomModuleCustomConfigResourceSelectorOutputReference | SccOrganizationCustomModuleCustomConfigResourceSelector): any;
export declare function sccOrganizationCustomModuleCustomConfigResourceSelectorToHclTerraform(struct?: SccOrganizationCustomModuleCustomConfigResourceSelectorOutputReference | SccOrganizationCustomModuleCustomConfigResourceSelector): any;
export declare class SccOrganizationCustomModuleCustomConfigResourceSelectorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SccOrganizationCustomModuleCustomConfigResourceSelector | undefined;
    set internalValue(value: SccOrganizationCustomModuleCustomConfigResourceSelector | undefined);
    private _resourceTypes?;
    get resourceTypes(): string[];
    set resourceTypes(value: string[]);
    get resourceTypesInput(): string[] | undefined;
}
export interface SccOrganizationCustomModuleCustomConfig {
    /**
    * Text that describes the vulnerability or misconfiguration that the custom
    * module detects. This explanation is returned with each finding instance to
    * help investigators understand the detected issue. The text must be enclosed in quotation marks.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#description SccOrganizationCustomModule#description}
    */
    readonly description?: string;
    /**
    * An explanation of the recommended steps that security teams can take to resolve
    * the detected issue. This explanation is returned with each finding generated by
    * this module in the nextSteps property of the finding JSON.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#recommendation SccOrganizationCustomModule#recommendation}
    */
    readonly recommendation: string;
    /**
    * The severity to assign to findings generated by the module. Possible values: ["CRITICAL", "HIGH", "MEDIUM", "LOW"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#severity SccOrganizationCustomModule#severity}
    */
    readonly severity: string;
    /**
    * custom_output block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#custom_output SccOrganizationCustomModule#custom_output}
    */
    readonly customOutput?: SccOrganizationCustomModuleCustomConfigCustomOutput;
    /**
    * predicate block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#predicate SccOrganizationCustomModule#predicate}
    */
    readonly predicate: SccOrganizationCustomModuleCustomConfigPredicate;
    /**
    * resource_selector block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#resource_selector SccOrganizationCustomModule#resource_selector}
    */
    readonly resourceSelector: SccOrganizationCustomModuleCustomConfigResourceSelector;
}
export declare function sccOrganizationCustomModuleCustomConfigToTerraform(struct?: SccOrganizationCustomModuleCustomConfigOutputReference | SccOrganizationCustomModuleCustomConfig): any;
export declare function sccOrganizationCustomModuleCustomConfigToHclTerraform(struct?: SccOrganizationCustomModuleCustomConfigOutputReference | SccOrganizationCustomModuleCustomConfig): any;
export declare class SccOrganizationCustomModuleCustomConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SccOrganizationCustomModuleCustomConfig | undefined;
    set internalValue(value: SccOrganizationCustomModuleCustomConfig | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _recommendation?;
    get recommendation(): string;
    set recommendation(value: string);
    get recommendationInput(): string | undefined;
    private _severity?;
    get severity(): string;
    set severity(value: string);
    get severityInput(): string | undefined;
    private _customOutput;
    get customOutput(): SccOrganizationCustomModuleCustomConfigCustomOutputOutputReference;
    putCustomOutput(value: SccOrganizationCustomModuleCustomConfigCustomOutput): void;
    resetCustomOutput(): void;
    get customOutputInput(): SccOrganizationCustomModuleCustomConfigCustomOutput | undefined;
    private _predicate;
    get predicate(): SccOrganizationCustomModuleCustomConfigPredicateOutputReference;
    putPredicate(value: SccOrganizationCustomModuleCustomConfigPredicate): void;
    get predicateInput(): SccOrganizationCustomModuleCustomConfigPredicate | undefined;
    private _resourceSelector;
    get resourceSelector(): SccOrganizationCustomModuleCustomConfigResourceSelectorOutputReference;
    putResourceSelector(value: SccOrganizationCustomModuleCustomConfigResourceSelector): void;
    get resourceSelectorInput(): SccOrganizationCustomModuleCustomConfigResourceSelector | undefined;
}
export interface SccOrganizationCustomModuleTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#create SccOrganizationCustomModule#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#delete SccOrganizationCustomModule#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#update SccOrganizationCustomModule#update}
    */
    readonly update?: string;
}
export declare function sccOrganizationCustomModuleTimeoutsToTerraform(struct?: SccOrganizationCustomModuleTimeouts | cdktf.IResolvable): any;
export declare function sccOrganizationCustomModuleTimeoutsToHclTerraform(struct?: SccOrganizationCustomModuleTimeouts | cdktf.IResolvable): any;
export declare class SccOrganizationCustomModuleTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SccOrganizationCustomModuleTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: SccOrganizationCustomModuleTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module google_scc_organization_custom_module}
*/
export declare class SccOrganizationCustomModule extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_scc_organization_custom_module";
    /**
    * Generates CDKTF code for importing a SccOrganizationCustomModule resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the SccOrganizationCustomModule to import
    * @param importFromId The id of the existing SccOrganizationCustomModule that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the SccOrganizationCustomModule to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/scc_organization_custom_module google_scc_organization_custom_module} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options SccOrganizationCustomModuleConfig
    */
    constructor(scope: Construct, id: string, config: SccOrganizationCustomModuleConfig);
    get ancestorModule(): string;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _enablementState?;
    get enablementState(): string;
    set enablementState(value: string);
    get enablementStateInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get lastEditor(): string;
    get name(): string;
    private _organization?;
    get organization(): string;
    set organization(value: string);
    get organizationInput(): string | undefined;
    get updateTime(): string;
    private _customConfig;
    get customConfig(): SccOrganizationCustomModuleCustomConfigOutputReference;
    putCustomConfig(value: SccOrganizationCustomModuleCustomConfig): void;
    get customConfigInput(): SccOrganizationCustomModuleCustomConfig | undefined;
    private _timeouts;
    get timeouts(): SccOrganizationCustomModuleTimeoutsOutputReference;
    putTimeouts(value: SccOrganizationCustomModuleTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | SccOrganizationCustomModuleTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
