/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface VertexAiFeatureOnlineStoreFeatureviewConfig extends cdktf.TerraformMetaArguments {
    /**
    * The name of the FeatureOnlineStore to use for the featureview.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/vertex_ai_feature_online_store_featureview#feature_online_store VertexAiFeatureOnlineStoreFeatureview#feature_online_store}
    */
    readonly featureOnlineStore: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/vertex_ai_feature_online_store_featureview#id VertexAiFeatureOnlineStoreFeatureview#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * A set of key/value label pairs to assign to this FeatureView.
    *
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/vertex_ai_feature_online_store_featureview#labels VertexAiFeatureOnlineStoreFeatureview#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Name of the FeatureView. This value may be up to 60 characters, and valid characters are [a-z0-9_]. The first character cannot be a number.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/vertex_ai_feature_online_store_featureview#name VertexAiFeatureOnlineStoreFeatureview#name}
    */
    readonly name?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/vertex_ai_feature_online_store_featureview#project VertexAiFeatureOnlineStoreFeatureview#project}
    */
    readonly project?: string;
    /**
    * The region for the resource. It should be the same as the featureonlinestore region.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/vertex_ai_feature_online_store_featureview#region VertexAiFeatureOnlineStoreFeatureview#region}
    */
    readonly region: string;
    /**
    * big_query_source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/vertex_ai_feature_online_store_featureview#big_query_source VertexAiFeatureOnlineStoreFeatureview#big_query_source}
    */
    readonly bigQuerySource?: VertexAiFeatureOnlineStoreFeatureviewBigQuerySource;
    /**
    * feature_registry_source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/vertex_ai_feature_online_store_featureview#feature_registry_source VertexAiFeatureOnlineStoreFeatureview#feature_registry_source}
    */
    readonly featureRegistrySource?: VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySource;
    /**
    * sync_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/vertex_ai_feature_online_store_featureview#sync_config VertexAiFeatureOnlineStoreFeatureview#sync_config}
    */
    readonly syncConfig?: VertexAiFeatureOnlineStoreFeatureviewSyncConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/vertex_ai_feature_online_store_featureview#timeouts VertexAiFeatureOnlineStoreFeatureview#timeouts}
    */
    readonly timeouts?: VertexAiFeatureOnlineStoreFeatureviewTimeouts;
}
export interface VertexAiFeatureOnlineStoreFeatureviewBigQuerySource {
    /**
    * Columns to construct entityId / row keys. Start by supporting 1 only.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/vertex_ai_feature_online_store_featureview#entity_id_columns VertexAiFeatureOnlineStoreFeatureview#entity_id_columns}
    */
    readonly entityIdColumns: string[];
    /**
    * The BigQuery view URI that will be materialized on each sync trigger based on FeatureView.SyncConfig.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/vertex_ai_feature_online_store_featureview#uri VertexAiFeatureOnlineStoreFeatureview#uri}
    */
    readonly uri: string;
}
export declare function vertexAiFeatureOnlineStoreFeatureviewBigQuerySourceToTerraform(struct?: VertexAiFeatureOnlineStoreFeatureviewBigQuerySourceOutputReference | VertexAiFeatureOnlineStoreFeatureviewBigQuerySource): any;
export declare function vertexAiFeatureOnlineStoreFeatureviewBigQuerySourceToHclTerraform(struct?: VertexAiFeatureOnlineStoreFeatureviewBigQuerySourceOutputReference | VertexAiFeatureOnlineStoreFeatureviewBigQuerySource): any;
export declare class VertexAiFeatureOnlineStoreFeatureviewBigQuerySourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): VertexAiFeatureOnlineStoreFeatureviewBigQuerySource | undefined;
    set internalValue(value: VertexAiFeatureOnlineStoreFeatureviewBigQuerySource | undefined);
    private _entityIdColumns?;
    get entityIdColumns(): string[];
    set entityIdColumns(value: string[]);
    get entityIdColumnsInput(): string[] | undefined;
    private _uri?;
    get uri(): string;
    set uri(value: string);
    get uriInput(): string | undefined;
}
export interface VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySourceFeatureGroups {
    /**
    * Identifier of the feature group.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/vertex_ai_feature_online_store_featureview#feature_group_id VertexAiFeatureOnlineStoreFeatureview#feature_group_id}
    */
    readonly featureGroupId: string;
    /**
    * Identifiers of features under the feature group.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/vertex_ai_feature_online_store_featureview#feature_ids VertexAiFeatureOnlineStoreFeatureview#feature_ids}
    */
    readonly featureIds: string[];
}
export declare function vertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySourceFeatureGroupsToTerraform(struct?: VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySourceFeatureGroups | cdktf.IResolvable): any;
export declare function vertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySourceFeatureGroupsToHclTerraform(struct?: VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySourceFeatureGroups | cdktf.IResolvable): any;
export declare class VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySourceFeatureGroupsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySourceFeatureGroups | cdktf.IResolvable | undefined;
    set internalValue(value: VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySourceFeatureGroups | cdktf.IResolvable | undefined);
    private _featureGroupId?;
    get featureGroupId(): string;
    set featureGroupId(value: string);
    get featureGroupIdInput(): string | undefined;
    private _featureIds?;
    get featureIds(): string[];
    set featureIds(value: string[]);
    get featureIdsInput(): string[] | undefined;
}
export declare class VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySourceFeatureGroupsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySourceFeatureGroups[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySourceFeatureGroupsOutputReference;
}
export interface VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySource {
    /**
    * feature_groups block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/vertex_ai_feature_online_store_featureview#feature_groups VertexAiFeatureOnlineStoreFeatureview#feature_groups}
    */
    readonly featureGroups: VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySourceFeatureGroups[] | cdktf.IResolvable;
}
export declare function vertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySourceToTerraform(struct?: VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySourceOutputReference | VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySource): any;
export declare function vertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySourceToHclTerraform(struct?: VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySourceOutputReference | VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySource): any;
export declare class VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySource | undefined;
    set internalValue(value: VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySource | undefined);
    private _featureGroups;
    get featureGroups(): VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySourceFeatureGroupsList;
    putFeatureGroups(value: VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySourceFeatureGroups[] | cdktf.IResolvable): void;
    get featureGroupsInput(): cdktf.IResolvable | VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySourceFeatureGroups[] | undefined;
}
export interface VertexAiFeatureOnlineStoreFeatureviewSyncConfig {
    /**
    * Cron schedule (https://en.wikipedia.org/wiki/Cron) to launch scheduled runs.
    * To explicitly set a timezone to the cron tab, apply a prefix in the cron tab: "CRON_TZ=${IANA_TIME_ZONE}" or "TZ=${IANA_TIME_ZONE}".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/vertex_ai_feature_online_store_featureview#cron VertexAiFeatureOnlineStoreFeatureview#cron}
    */
    readonly cron?: string;
}
export declare function vertexAiFeatureOnlineStoreFeatureviewSyncConfigToTerraform(struct?: VertexAiFeatureOnlineStoreFeatureviewSyncConfigOutputReference | VertexAiFeatureOnlineStoreFeatureviewSyncConfig): any;
export declare function vertexAiFeatureOnlineStoreFeatureviewSyncConfigToHclTerraform(struct?: VertexAiFeatureOnlineStoreFeatureviewSyncConfigOutputReference | VertexAiFeatureOnlineStoreFeatureviewSyncConfig): any;
export declare class VertexAiFeatureOnlineStoreFeatureviewSyncConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): VertexAiFeatureOnlineStoreFeatureviewSyncConfig | undefined;
    set internalValue(value: VertexAiFeatureOnlineStoreFeatureviewSyncConfig | undefined);
    private _cron?;
    get cron(): string;
    set cron(value: string);
    resetCron(): void;
    get cronInput(): string | undefined;
}
export interface VertexAiFeatureOnlineStoreFeatureviewTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/vertex_ai_feature_online_store_featureview#create VertexAiFeatureOnlineStoreFeatureview#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/vertex_ai_feature_online_store_featureview#delete VertexAiFeatureOnlineStoreFeatureview#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/vertex_ai_feature_online_store_featureview#update VertexAiFeatureOnlineStoreFeatureview#update}
    */
    readonly update?: string;
}
export declare function vertexAiFeatureOnlineStoreFeatureviewTimeoutsToTerraform(struct?: VertexAiFeatureOnlineStoreFeatureviewTimeouts | cdktf.IResolvable): any;
export declare function vertexAiFeatureOnlineStoreFeatureviewTimeoutsToHclTerraform(struct?: VertexAiFeatureOnlineStoreFeatureviewTimeouts | cdktf.IResolvable): any;
export declare class VertexAiFeatureOnlineStoreFeatureviewTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): VertexAiFeatureOnlineStoreFeatureviewTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: VertexAiFeatureOnlineStoreFeatureviewTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/vertex_ai_feature_online_store_featureview google_vertex_ai_feature_online_store_featureview}
*/
export declare class VertexAiFeatureOnlineStoreFeatureview extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_vertex_ai_feature_online_store_featureview";
    /**
    * Generates CDKTF code for importing a VertexAiFeatureOnlineStoreFeatureview resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the VertexAiFeatureOnlineStoreFeatureview to import
    * @param importFromId The id of the existing VertexAiFeatureOnlineStoreFeatureview that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/vertex_ai_feature_online_store_featureview#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the VertexAiFeatureOnlineStoreFeatureview to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/vertex_ai_feature_online_store_featureview google_vertex_ai_feature_online_store_featureview} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options VertexAiFeatureOnlineStoreFeatureviewConfig
    */
    constructor(scope: Construct, id: string, config: VertexAiFeatureOnlineStoreFeatureviewConfig);
    get createTime(): string;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _featureOnlineStore?;
    get featureOnlineStore(): string;
    set featureOnlineStore(value: string);
    get featureOnlineStoreInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    get regionInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get updateTime(): string;
    private _bigQuerySource;
    get bigQuerySource(): VertexAiFeatureOnlineStoreFeatureviewBigQuerySourceOutputReference;
    putBigQuerySource(value: VertexAiFeatureOnlineStoreFeatureviewBigQuerySource): void;
    resetBigQuerySource(): void;
    get bigQuerySourceInput(): VertexAiFeatureOnlineStoreFeatureviewBigQuerySource | undefined;
    private _featureRegistrySource;
    get featureRegistrySource(): VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySourceOutputReference;
    putFeatureRegistrySource(value: VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySource): void;
    resetFeatureRegistrySource(): void;
    get featureRegistrySourceInput(): VertexAiFeatureOnlineStoreFeatureviewFeatureRegistrySource | undefined;
    private _syncConfig;
    get syncConfig(): VertexAiFeatureOnlineStoreFeatureviewSyncConfigOutputReference;
    putSyncConfig(value: VertexAiFeatureOnlineStoreFeatureviewSyncConfig): void;
    resetSyncConfig(): void;
    get syncConfigInput(): VertexAiFeatureOnlineStoreFeatureviewSyncConfig | undefined;
    private _timeouts;
    get timeouts(): VertexAiFeatureOnlineStoreFeatureviewTimeoutsOutputReference;
    putTimeouts(value: VertexAiFeatureOnlineStoreFeatureviewTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | VertexAiFeatureOnlineStoreFeatureviewTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
